/*************************************************************
 * current_main.c
 *
 * current measurement main module
 *
 * Copyright (C)SEIKO EPSON CORPORATION 2009. All rights reserved.
 ************************************************************/

#include <stdio.h>
#include <s1c176xx.h>

#ifdef	PE_CURRENT_MEASURE
#include <osc_api.h>
#include <port_api.h>
#include <mux_api.h>
#include <clg_api.h>
#include "main.h"

#ifdef	PE_VD1
#include <vd1_api.h>
#endif

// prototype
void currentMeasurementMain(void);
static void startIOSC(void);
static void goSleep(void);
static void goHaltCPUOSC1(void);
static void goHaltCPUOSC1_3(void);
static void goHaltCPUOSC1_3_I(void);
static unsigned char currentMenuDisp(void);
static unsigned char currentMenuInput(unsigned char menuMax);


// sub menu table
static MENU_TBL currentMainMenu[] = {
	{ "Sleep                "	, goSleep					},
	{ "Halt with OSC1       "	, goHaltCPUOSC1				},
	{ "Halt with OSC1/3     "	, goHaltCPUOSC1_3			},
	{ "Halt with OSC1/3/IOSC"	, goHaltCPUOSC1_3_I			},
	{ NULL						, NULL						}
};

/*
 * sample program for current measurement
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void currentMeasurementMain(void)
{
	unsigned char	menuMax;								// MAX menu number
	unsigned char	inputNo;								// key input number

	printf("<<< Current measurement demonstration start >>>\n");

	// port all off
	MUX_init();
	PORT_init();

	// IOSC start
	startIOSC();

	while(1) {
		// menu display
		menuMax = currentMenuDisp();

		 // wait input menu number
		inputNo = currentMenuInput(menuMax);

		 // select peripheral test
		if(inputNo != MENU_ERROR) {
			currentMainMenu[inputNo-1U].function();
		}
	}
}

/*
 * start all OSC(OSC1, OSC3, IOSC).
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void startIOSC(void)
{
	OSC_setWaitCycle(OSC_SELIOSC_64, OSC_SELOSC3_512);			// set wait cycle
	OSC_controlOscillation(OSC_IOSC_ENABLE | OSC_OSC1_ENABLE | OSC_OSC3_ENABLE);	// start all OSC
}

/*
 * sleep CPU
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void goSleep(void)
{

#ifdef	PE_VD1
	VD1_setMode( VD1_OFF );			// heavy load protection mode disable
#endif

	printf("sleeping\n");
	asm ( "slp" );
	asm ( "nop" );

#ifdef	PE_VD1
	VD1_setMode( VD1_ON );			// heavy load protection mode enable
#endif
}

/*
 * change OSC3 to OSC1 and stop IOSC and OSC3, halt CPU
 * this function must be called when OSC3 and OSC1 are active
 * param	void
 * return	void
 * history	:	2009/12/25
 * 			:   2010/03/18 add PCLK Control
 */
static void goHaltCPUOSC1(void)
{
	OSC_setClockSource(OSC_SELHSCLK_OSC3, OSC_SELCLKSRC_OSC1);	// change clock source
	OSC_controlOscillation(OSC_IOSC_DISABLE | OSC_OSC1_ENABLE | OSC_OSC3_DISABLE);	// stop IOSC & OSC3

#ifdef	PE_VD1
	VD1_setMode( VD1_OFF );			// heavy load protection mode disable
#endif

	// PCLK disable.
	CLG_setPCLKEnable(CLG_PCLK_DISABLE);

	printf("halt\n");
	asm( "halt" );
	asm( "nop" );

	// PCLK enable.
	CLG_setPCLKEnable(CLG_PCLK_ENABLE);

#ifdef	PE_VD1
	VD1_setMode( VD1_ON );			// heavy load protection mode enable
#endif
}

/*
 * stop IOSC and halt CPU
 * this function must be called when OSC3 and OSC1 are active
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void goHaltCPUOSC1_3(void)
{
	OSC_controlOscillation(OSC_IOSC_DISABLE | OSC_OSC1_ENABLE | OSC_OSC3_ENABLE);	// stop IOSC

	printf("halt\n");
	asm( "halt" );
	asm( "nop" );

}

/*
 * halt CPU
 * this function must be called when OSC3 and OSC1, IOSC is active
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void goHaltCPUOSC1_3_I(void)
{

	printf("halt\n");
	asm( "halt" );
	asm( "nop" );

}

/*
 * display menu
 * param	void
 * return	unsigned char							MAX menu No.
 * history	:	2009/12/25
 */
static unsigned char currentMenuDisp(void)
{
	unsigned char	i;
	unsigned char	buff[65];

	// menu display
	for(i = 0U; currentMainMenu[i].menuString != NULL; i++) {
		sprintf(&buff[(i%2U)*22U], "%2d. %23s\n", i+1U, currentMainMenu[i].menuString);

		if((i % 2U) == 0x01U) {
			printf(buff);
		}
	}
	printf("\n\nPlease input number.\n> ");

	return	i;
}

/*
 * get menu number and check
 * param	unsigned char menuMax					MAX menu No.
 * return	int										input menu No.
 * history	:	2009/12/25
 */
static unsigned char currentMenuInput(unsigned char menuMax)
{
	unsigned char	inputString[5];							// user input data buffer
	unsigned char	inputNo;								// input menu number

	// input menu number:
	fgets((char*)&inputString[0], sizeof(inputString), stdin);
	sscanf(inputString, "%d", (char*)&inputNo);

	// range check:
	if((inputNo <= 0) || (inputNo > menuMax)) {
		inputNo = MENU_ERROR;
	}
	return	inputNo;
}

#endif	// end of PE_CURRENT_MEASURE
