/*************************************************************
 * main.c
 *
 * main module
 *
 * Copyright (C)SEIKO EPSON CORPORATION 2009. All rights reserved.
 ************************************************************/

#include <stdio.h>
#include <mux_api.h>
#include <osc_api.h>
#include <psc_api.h>
#include <vd1_api.h>
#include "main.h"

extern MENU_TBL mainMenu[];									// menu table

int main(void);
static unsigned char menuDisp(void);
static unsigned char menuInput(unsigned char menuMax);

extern	void startAllOSC(void);


/*
 * main module. display menu and get command from user, call sub modules.
 * param	void
 * return	void
 * history	:	2009/12/25
 */

int main(void)
{
	unsigned char	menuMax;								// MAX menu number
	unsigned char	inputNo;								// key input number

	// heavy load protection mode enable
	VD1_setMode( VD1_ON );

	// set OSC3/OSC4 port
	MUX_setOSCport(MUX_FOUT1_OFF, MUX_FOUT1_OFF, MUX_OFF);

	// start all OSC
	startAllOSC();

	// run prescaler
	PSC_setPrescalerControl(PSC_DEBUG_RUN, PSC_NORMAL_RUN);

	// main loop
	while(1) {
		// menu display
		menuMax = menuDisp();

		// wait input menu number
		inputNo = menuInput(menuMax);

		// select peripheral test
		if(inputNo != MENU_ERROR) {
			mainMenu[inputNo-1U].function();
		}
	}
	// stop prescaler
	PSC_setPrescalerControl(PSC_DEBUG_STOP, PSC_NORMAL_STOP);

	return 0;
}

/*
 * display menu module.
 * param	void
 * return	unsigned char							MAX menu No.
 * history	:	2009/12/25
 */
static unsigned char menuDisp(void)
{
	unsigned char	i;
	unsigned char	buff[65];

	// menu display
	for(i = 0; mainMenu[i].menuString != NULL; i++) {
		sprintf(&buff[(i%2)*25], "%2d. %s\n", i+1, mainMenu[i].menuString);

		if((i % 2) == 0x01) {
			printf(buff);
		}
	}
	if((i % 2) == 0x01) {
		printf(buff);
	}
	printf("\n\nPlease input number.\n> ");

	return	i;
}

/*
 * get command from user module.
 * param	unsigned char menuMax					MAX menu No.
 * return	int										input menu No.
 * history	:	2009/12/25
 */
static unsigned char menuInput(unsigned char menuMax)
{
	unsigned char	inputString[5];							// user input data buffer
	unsigned char	inputNo;								// input menu number

	// input menu number
	fgets((char*)&inputString[0], sizeof(inputString), stdin);
	sscanf(inputString, "%d", (char*)&inputNo);

	// range check
	if((inputNo <= 0) || (inputNo > menuMax)) {
		inputNo = MENU_ERROR;
	}
	return	inputNo;
}

