/*************************************************************
 * osc_main.c
 *
 * OSC main module
 *
 * Copyright (C)SEIKO EPSON CORPORATION 2009. All rights reserved.
 ************************************************************/

#include <stdio.h>
#include <s1c176xx.h>

#ifdef	PE_OSC
#include <osc_api.h>

#define	OSC_MAIN_DISPLAY_MESSAGE_NUM	9		// number of messages
#define	OSC_OSC1_WAIT					3000	// OSC1 start waiting time

#ifdef	PE_VD1
#include <vd1_api.h>
#endif

/* prototype */
void oscMain(void);
static void startIOSC(void);
void startAllOSC(void);
static void changeIOSCtoOSC3(void);
static void changeOSC3toOSC1(void);
static void changeOSC1toIOSC(void);
static void waitUseSystemClock(unsigned short x, unsigned long sysClk);


/*
 * OSC sample program
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void oscMain(void)
{
	unsigned char	i;													// loop counter
	unsigned char	buff[65];											// display buffer

	printf("<<< OSC demonstration start >>>\n\n");

	// start IOSC
	startIOSC();

	for(i = 1; i < (OSC_MAIN_DISPLAY_MESSAGE_NUM + 1); i++) {
		sprintf(buff, "IOSC *** %d ***\n", i);
		printf(buff);
		waitUseSystemClock(0, IOSC_CLK);
	}

	printf("*** Change from IOSC to OSC3 ***\n");

	// start OSC3 and stop IOSC
	changeIOSCtoOSC3();

	for(i = 1; i < (OSC_MAIN_DISPLAY_MESSAGE_NUM + 1); i++) {
		sprintf(buff, "OSC3 *** %d ***\n", i);
		printf(buff);
		waitUseSystemClock(0, OSC3_CLK);
	}

	printf("*** Change from OSC3 to OSC1 ***\n");

	// start OSC1 and stop OSC3
	changeOSC3toOSC1();

	for(i = 1; i < (OSC_MAIN_DISPLAY_MESSAGE_NUM + 1); i++) {
		sprintf(buff, "OSC1 *** %d ***\n", i);
		printf(buff);
		waitUseSystemClock(0, OSC1_CLK);
	}

	printf("*** Change from OSC1 to IOSC ***\n");

	// start IOSC and stop OSC1
	changeOSC1toIOSC();

	for(i = 1; i < (OSC_MAIN_DISPLAY_MESSAGE_NUM + 1); i++) {
		sprintf(buff, "IOSC *** %d ***\n", i);
		printf(buff);
		waitUseSystemClock(0, IOSC_CLK);
	}

	printf("<<< OSC demonstration finish >>>\n\n");

	// start all OSC
	startAllOSC();
}

/*
 * start IOSC and stop OSC1 and OSC3.
 * param	void
 * return	void
 * history	:	2009/12/25
 *          :   2010/03/16 change start IOSC
 */
static void startIOSC(void)
{
	OSC_setWaitCycle(OSC_SELIOSC_64, OSC_SELOSC3_512);			// set wait cycle
	OSC_controlOscillation(OSC_IOSC_ENABLE | OSC_OSC1_DISABLE | OSC_OSC3_ENABLE);	// start IOSC

	OSC_setClockSource(OSC_SELHSCLK_IOSC, OSC_SELCLKSRC_HSCLK);	// change clock source

	OSC_controlOscillation(OSC_IOSC_ENABLE | OSC_OSC1_DISABLE | OSC_OSC3_DISABLE);	// stop OSC1 amd OSC3
}

/*
 * start all OSC.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void startAllOSC(void)
{
	OSC_setWaitCycle(OSC_SELIOSC_64, OSC_SELOSC3_512);			// set wait cycle
	OSC_controlOscillation(OSC_IOSC_ENABLE | OSC_OSC1_ENABLE | OSC_OSC3_ENABLE);		// start all OSC

	OSC_setClockSource(OSC_SELHSCLK_OSC3, OSC_SELCLKSRC_HSCLK);	// change clock source

	OSC_controlOscillation(OSC_IOSC_DISABLE | OSC_OSC1_ENABLE | OSC_OSC3_ENABLE);		// stop IOSC
	waitUseSystemClock(OSC_OSC1_WAIT, OSC3_CLK);
}

/*
 * start OSC3 and change a system clock to OSC3, stop IOSC.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void changeIOSCtoOSC3(void)
{

	OSC_setWaitCycle(OSC_SELIOSC_64, OSC_SELOSC3_512);			// set wait cycle
	OSC_controlOscillation(OSC_IOSC_ENABLE | OSC_OSC1_DISABLE | OSC_OSC3_ENABLE);		// start OSC3

	OSC_setClockSource(OSC_SELHSCLK_OSC3, OSC_SELCLKSRC_HSCLK);	// change clock source

	OSC_controlOscillation(OSC_IOSC_DISABLE | OSC_OSC1_DISABLE | OSC_OSC3_ENABLE);		// stop IOSC

}

/*
 * start OSC1 and change a system clock to OSC1, stop OSC3.
 * param	void
 * return	void
 * history	:	2009/12/25
 *          :   2010/03/03 add heavy load protection mode disable
 */
static void changeOSC3toOSC1(void)
{
	OSC_controlOscillation(OSC_IOSC_DISABLE | OSC_OSC1_ENABLE | OSC_OSC3_ENABLE);		// start OSC1

	OSC_setClockSource(OSC_SELHSCLK_OSC3, OSC_SELCLKSRC_OSC1);	// change clock source

	OSC_controlOscillation(OSC_IOSC_DISABLE | OSC_OSC1_ENABLE | OSC_OSC3_DISABLE);		// stop OSC3

#ifdef	PE_VD1
	VD1_setMode( VD1_OFF );			// heavy load protection mode disable
#endif

}

/*
 * start IOSC and change a system clock to IOSC, stop OSC1.
 * param	void
 * return	void
 * history	:	2009/12/25
 *          :   2010/03/03 add heavy load protection mode enable
 */
static void changeOSC1toIOSC(void)
{

	OSC_setWaitCycle(OSC_SELIOSC_64, OSC_SELOSC3_512);				// set wait cycle

#ifdef	PE_VD1
	VD1_setMode( VD1_ON );			// heavy load protection mode enable
#endif

	OSC_controlOscillation(OSC_IOSC_ENABLE | OSC_OSC1_ENABLE | OSC_OSC3_ENABLE);		// start OSC3 and IOSC

	OSC_setClockSource(OSC_SELHSCLK_IOSC, OSC_SELCLKSRC_HSCLK);		// change clock source

	OSC_controlOscillation(OSC_IOSC_ENABLE | OSC_OSC1_DISABLE | OSC_OSC3_DISABLE);	// stop OSC1 and OSC3
}

/*
 * wait X[msec] while running with system clock.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void waitUseSystemClock(unsigned short x, unsigned long sysClk)
{
	unsigned short	mil_ct;		// x mil sec counter
	unsigned long	clk_ct;		// system clock 1 mil sec counter

	if(x == 0) {
		for(mil_ct = 0; mil_ct < 0x100; mil_ct++) {
			;
		}
	} else {
		mil_ct = x;

		while(mil_ct > 0) {
			clk_ct = sysClk / 1000 / 7;

			while(clk_ct > 0) {
				clk_ct--;
			}
			mil_ct--;
		}
	}
}

#endif	// end of PE_OSC
