/*************************************************************
 * rfc_main.c
 *
 * RFC main module
 *
 * Copyright (C)SEIKO EPSON CORPORATION 2009. All rights reserved.
 ************************************************************/

#include <stdio.h>
#include <string.h>
#include <s1c176xx.h>

#ifdef	PE_RFC
#include <rfc_api.h>
#include <mux_api.h>
#include <osc_api.h>


/* flag value */
#define RFC_MAIN_REF 			0		// RFC is wait REF end
#define RFC_MAIN_SENA		 	1		// RFC is wait SENA end
#define RFC_MAIN_STOP 			2		// RFC is stopped

static volatile unsigned char	flgRFCRunStatus;	// RFC program running status flag
static volatile unsigned char	loopEndFlag;		// loop waiting flag


#define RFC_MAIN_MC_REFERENCE_VAL	0x00400000UL	// mc initial value for reference osc
#define RFC_MAIN_MC_SENSOR_VAL		0x00000000UL	// mc initial value for sonsor osc
#define RFC_MAIN_TC_REFERENCE_VAL	0x00000000UL	// tc initial value for reference osc

void rfcMain(void);
static void startRFCReference(void);
static void stopRFCReference(void);
static void startRFCSensorA(void);
static void stopRFCSensorA(void);
void rfcIntHandler(void)__attribute__ ((interrupt_handler));


// RFC main status
struct tag_RFC_MAIN_STATUS;
typedef struct tag_RFC_MAIN_STATUS {
	unsigned char			*message;			// print message
	volatile unsigned char	intFlag;			// RFC interrupt flags
	volatile unsigned char	nextRFCRunStatus;	// RFC program next status
	void	(*startFunction)(void);
	void	(*stopFunction)(void);
} RFC_MAIN_STATUS;

static RFC_MAIN_STATUS rfcMainStatus[] = {
	{
		"Reference",
		(RFC_TCOVFINT_OCCURRED | RFC_REFINT_OCCURRED),
		RFC_MAIN_SENA,
		startRFCReference,
		stopRFCReference
	},
	{
		"Sensor A",
		(RFC_MCOVFINT_OCCURRED | RFC_SENAINT_OCCURRED),
		RFC_MAIN_STOP,
		startRFCSensorA,
		stopRFCSensorA
	}
};

// RFC use port on/off
static MUX_USE_RFCPORT setUsePort = {									// settings parameter
	MUX_RFIN_ON,
	MUX_REF_ON,
	MUX_SENA_ON,
	MUX_SENB_OFF,
	MUX_RFCLK_ON
};


/*
 * RFC sample program
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void rfcMain(void)
{
	printf("<<< RFC demonstration start >>>\n");

	// set OSC and ports
	OSC_setRFCClock(OSC_RFCCLK_OSC1, OSC_RFCRATIO_1);
	OSC_controlRFC(OSC_RFCCLK_ENABLE);
	MUX_setRFCport(RFC_CH0, &setUsePort, MUX_ON);
	flgRFCRunStatus = RFC_MAIN_REF;
	
	while(flgRFCRunStatus != RFC_MAIN_STOP) {
		printf("%s\n", rfcMainStatus[flgRFCRunStatus].message);

		// start osc
		rfcMainStatus[flgRFCRunStatus].startFunction();
	
		// wait osc end
		loopEndFlag = 0;
		while(loopEndFlag == 0) {
			;
		}
		
		// stop osc
		rfcMainStatus[flgRFCRunStatus].stopFunction();
		flgRFCRunStatus = rfcMainStatus[flgRFCRunStatus].nextRFCRunStatus;
	}
	// stop OSC and ports
	MUX_setRFCport(RFC_CH0, &setUsePort, MUX_OFF);
	OSC_controlRFC(OSC_RFCCLK_DISABLE);

	printf("<<< RFC demonstration finish >>>\n");
}

/*
 * start RFC reference osc.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void startRFCReference(void)
{
	RFC_setRFC(RFC_ENABLE);
#ifdef	S1C17602
	RFC_setRFCChannel(RFC_CONVERSION_CH0);
#endif	// end of S1C17602
	RFC_setRFCMode(RFC_OSCMODE_RDC);
	RFC_initInt(RFC_INT_LEVEL3);
	RFC_setMeasurementCounter(((~RFC_MAIN_MC_REFERENCE_VAL) + 1) & 0x00ffffff);
	RFC_setTimeBaseCounter(RFC_MAIN_TC_REFERENCE_VAL & 0x00ffffff);
	asm("nop");
	asm("nop");
	asm("nop");

	RFC_controlInt(RFC_TCOVFINT_ENABLE | RFC_MCOVFINT_DISABLE |
		RFC_SENBINT_DISABLE | RFC_SENAINT_DISABLE | RFC_REFINT_ENABLE);

	RFC_setReferenceOscillation(RFC_REFOSC_START);
}


/*
 *  stop RFC reference osc.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void stopRFCReference(void)
{
	;
}

/*
 * start RFC sensor A osc.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void startRFCSensorA(void)
{
	RFC_controlInt(RFC_TCOVFINT_DISABLE | RFC_MCOVFINT_ENABLE |
		RFC_SENBINT_DISABLE | RFC_SENAINT_ENABLE | RFC_REFINT_DISABLE);

	RFC_setSensorAOscillation(RFC_SENAOSC_START);
}


/*
 *  stop RFC sensor A osc.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void stopRFCSensorA(void)
{
	RFC_controlInt(RFC_TCOVFINT_DISABLE | RFC_MCOVFINT_DISABLE |
		RFC_SENBINT_DISABLE | RFC_SENAINT_DISABLE | RFC_REFINT_DISABLE);

	RFC_initInt(RFC_INT_LEVEL0);
	RFC_setRFC(RFC_DISABLE);
}

/*
 * RFC interrupt handler.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void rfcIntHandler(void)
{
	unsigned long	MeasurementCountData;	//measurement counter data
	unsigned long	TimeBaseCountData;		//time base count data
	unsigned char	flgIntr;		// interrupt flag

	RFC_getMeasurementCounter(&MeasurementCountData);
	RFC_getTimeBaseCounter(&TimeBaseCountData);

	// get interrupt status
	RFC_checkIntFlag(&flgIntr);

	// check interrupt
	if((flgIntr & rfcMainStatus[flgRFCRunStatus].intFlag) != 0) {
		printf("measurement counter : %lx\n", MeasurementCountData);
		printf("time Base counter : %lx\n", TimeBaseCountData);
		RFC_resetIntFlag(rfcMainStatus[flgRFCRunStatus].intFlag);
		loopEndFlag = 1;
	}
}

#endif	// end of PE_RFC
