/*************************************************************
 * sleep_halt_main.c
 *
 * sleep / halt main module
 *
 * Copyright (C)SEIKO EPSON CORPORATION 2009. All rights reserved.
 ************************************************************/

#include <stdio.h>
#include <s1c176xx.h>

#ifdef	PE_SLEEP_HALT
#include <t16_api.h>
#include <port_api.h>

#ifdef	PE_VD1
#include <vd1_api.h>
#endif

// T16 timer counter max value
#define	SLEEP_HALT_MAIN_LOOP_MAX	5

static unsigned char t16LoopCt;			// T16 timer interrupt counter

// T16 timer functions
extern void t16SetCallBackFunc(void(*name)(void));
extern void t16ClearCallBackFunc(void);

//PORT P02 functions
extern void portSetCallBackFunc(unsigned char chNo, void(*name)(void));
extern void portClearCallBackFunc(unsigned char chNo);

// Prototype
void sleepHaltMain(void);
static void setPortInput(void);
static void clearPortInput(void);
static void startT16(unsigned char chNo);
static void stopT16(unsigned char chNo);
void t16CallBackFunction(void);
void portCallBackFunction(void);


/*
 * sleep/halt sample program
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void sleepHaltMain(void)
{
	printf("<<< Sleep/halt demonstration start >>>\n");
	
	// set a call back function to T16 interrupt handler
	t16SetCallBackFunc(&t16CallBackFunction);

	// start T16 timer
	startT16(T16_CH0);

	// wait T16 timer interrupt 5 times
	t16LoopCt = 0;
	while(t16LoopCt < SLEEP_HALT_MAIN_LOOP_MAX) {
		printf("go to halt mode\n");

		// halt CPU
		asm( "halt" );
		asm( "nop" );	
		
		printf("return from halt mode\n");
		t16LoopCt++;
	}

	// stop T16 timer
	stopT16(T16_CH0);

	// unregister a call back function from T16 timer handler
	t16ClearCallBackFunc();


	//set a call back function to P02 port interrupt handler.
	portSetCallBackFunc(PORT_NO_P0, &portCallBackFunction);

	// set P02 port for interrupt
	setPortInput();

	printf("go to sleep mode\n");

	// sleep CPU
#ifdef	PE_VD1
	VD1_setMode( VD1_OFF );			// heavy load protection mode disable
#endif
	asm ( "slp" );
	asm ( "nop" );	
#ifdef	PE_VD1
	VD1_setMode( VD1_ON );			// heavy load protection mode enable
#endif

	printf("return from sleep mode\n");

	// clear P02 port settings
	clearPortInput();
	
	// clear a call back function from P02 port handler.
	portClearCallBackFunc(PORT_NO_P0);

	printf("<<< Sleep/halt demonstration finish >>>\n");
}

/*
 * set registers for interrupt inputs.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void setPortInput(void)
{
	// set input settings
	PORT_setChatteringFilter(PORT_CHATNO_P030, PORT_CHATTIME_16384);
	PORT_controlPullup(PORT_NO_P0, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);
	PORT_controlSchmittTrigger(PORT_NO_P0, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);
	PORT_controlOutput(PORT_NO_P0, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);
	PORT_controlInput(PORT_NO_P0, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);
	PORT_setIntEdge(PORT_NO_P0, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_ENABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);
	PORT_initInt(PORT_NO_P0, PORT_INT_LEVEL3);
	PORT_controlInt(PORT_NO_P0, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_ENABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);
}

/*
 * clear registers for interrupt inputs.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
static void clearPortInput(void)
{
	// clear input settings
	PORT_controlInt(PORT_NO_P0, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);
	PORT_initInt(PORT_NO_P0, PORT_INT_LEVEL0);
	PORT_setIntEdge(PORT_NO_P0, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);
	PORT_controlInput(PORT_NO_P0, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);
	PORT_controlOutput(PORT_NO_P0, PORT_PX0_DISABLE | PORT_PX1_DISABLE | PORT_PX2_DISABLE | PORT_PX3_DISABLE |
									PORT_PX4_DISABLE | PORT_PX5_DISABLE | PORT_PX6_DISABLE | PORT_PX7_DISABLE);
	PORT_controlSchmittTrigger(PORT_NO_P0, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);
	PORT_controlPullup(PORT_NO_P0, PORT_PX0_ENABLE | PORT_PX1_ENABLE | PORT_PX2_ENABLE | PORT_PX3_ENABLE |
									PORT_PX4_ENABLE | PORT_PX5_ENABLE | PORT_PX6_ENABLE | PORT_PX7_ENABLE);
	PORT_setChatteringFilter(PORT_CHATNO_P030, PORT_CHATTIME_NONE);
}

/*
 * start T16 timer for 1 sec interval.
 * param	T16 channel number.
 * return	void
 * history	:	2009/12/25
 */
static void startT16(unsigned char chNo)
{
	T16_TIM_MODE	mode;	// timer mode setting

	mode.ckactv	= T16_TIMMODE_ACTVL;
	mode.cksl	= T16_TIMMODE_INTERNAL;
	mode.trmd	= T16_TIMMODE_REPEAT;
	T16_init(chNo, T16_CNTCLK_16384, &mode, OSC3_CLK/16384);
	
	T16_initInt(chNo, T16_INT_LEVEL3);
	T16_controlInt(chNo, T16_INT_ENABLE);
	T16_setTimerRun(chNo, T16_TIMER_RUN);
}

/*
 * stop T16 timer.
 * param	T16 channel number.
 * return	void
 * history	:	2009/12/25
 */
static void stopT16(unsigned char chNo)
{
	T16_setTimerRun(chNo, T16_TIMER_STOP);
	T16_controlInt(chNo, T16_INT_DISABLE);
	T16_initInt(chNo, T16_INT_LEVEL0);
}

/*
 * T16 timer call back function.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void t16CallBackFunction(void)
{
	;
}

/*
 * PORT P02 interrupt handler
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void portCallBackFunction(void)
{
	;
}

#endif	// end of PE_SLEEP_HALT
