/*************************************************************
 * t16_main.c
 *
 * 16-bit timer main module
 *
 * Copyright (C)SEIKO EPSON CORPORATION 2009. All rights reserved.
 ************************************************************/

#include <stdio.h>
#include <s1c176xx.h>

#ifdef	PE_T16
#include <t16_api.h>

#define	T16_MAIN_LOOP_CT_MAX	10						// loop counter max
#define	T16_MAIN_CH				T16_CH0					// T16 ch

static unsigned short	t16BufCounter[T16_MAIN_LOOP_CT_MAX] = {0};	// counter record buffer
static volatile unsigned char	t16LoopCt;									// loop counter

/* prototype */
void t16Main(void);
static void startT16(unsigned char chNo);
static void stopT16(unsigned char chNo);
void t16IntHandler(void)__attribute__((interrupt_handler));
void t16SetCallBackFunc(void(*name)(void));
void t16ClearCallBackFunc(void);

static void (*callBackFunction)(void) = 0;		// call back function

/*
 * T16 timer sample program
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void t16Main(void)
{
	printf("<<< T16 timer demonstration start >>>\n");
	
	// start T16 timer
	startT16(T16_MAIN_CH);

	t16LoopCt = 0;
	while(t16LoopCt < T16_MAIN_LOOP_CT_MAX) {
		asm( "halt" );
		asm( "nop" );
		t16LoopCt++;	// counter increment after wakeup
	}

	// stop T16 timer
	stopT16(T16_MAIN_CH);

	// display result
	t16LoopCt = 0;
	while(t16LoopCt < T16_MAIN_LOOP_CT_MAX) {
		t16LoopCt++;
		printf("T16 interrupt %d time, count data at this time : %d\n", t16LoopCt, t16BufCounter[t16LoopCt - 1U]);
	}

	printf("<<< T16 timer demonstration finish >>>\n");
}

/*
 * start T16 timer for 1 sec interval.
 * param	T16 channel number.
 * return	void
 * history	:	2009/12/25
 */
static void startT16(unsigned char chNo)
{
	T16_TIM_MODE	mode;	// timer mode setting

	mode.ckactv	= T16_TIMMODE_ACTVL;
	mode.cksl	= T16_TIMMODE_INTERNAL;
	mode.trmd	= T16_TIMMODE_REPEAT;

	T16_init(chNo, T16_CNTCLK_16384, &mode, OSC3_CLK/16384);
	T16_initInt(chNo, T16_INT_LEVEL7);
	T16_controlInt(chNo, T16_INT_ENABLE);
	T16_setTimerRun(chNo, T16_TIMER_RUN);
}

/*
 * stop T16 timer.
 * param	T16 channel number.
 * return	void
 * history	:	2009/12/25
 */
static void stopT16(unsigned char chNo)
{
	T16_setTimerRun(chNo, T16_TIMER_STOP);
	T16_controlInt(chNo, T16_INT_DISABLE);
	T16_initInt(chNo, T16_INT_LEVEL0);
}

/*
 * T16 interrupt handler
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void t16IntHandler(void)
{
	// reset interrupt flag
	T16_resetIntFlag(T16_MAIN_CH);

	if(callBackFunction != 0) {
		callBackFunction();			// call back
	} else if(t16LoopCt < T16_MAIN_LOOP_CT_MAX) {
		T16_getCounterData(T16_MAIN_CH, &t16BufCounter[t16LoopCt]);
	} else {
		;
	}
}

/*
 * set interrupt call back function.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void t16SetCallBackFunc(void(*name)(void))
{
	callBackFunction = name;
}

/*
 * clear interrupt call back function.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void t16ClearCallBackFunc(void)
{
	callBackFunction = 0;
}

#endif	// end of PE_T16
