/******************************************************************
 * i2cm_api.h
 * 
 * I2C master driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef I2CM_API_H_
#define I2CM_API_H_

#include <i2cm.h>

/******************************************
 * definition of "define"
 ******************************************/

// I2C master driver return code.
#define	I2CM_SUCCESS				 0								// success
#define	I2CM_INVALID_PARAMETER		-1								// invalid parameter
#define	I2CM_FAILURE				-2								// failure

// I2C master interrupt level.
enum {
	I2CM_INT_LEVEL0 = 0x00,											// 0x00:interrupt level 0
	I2CM_INT_LEVEL1,												// 0x01:interrupt level 1
	I2CM_INT_LEVEL2,												// 0x02:interrupt level 2
	I2CM_INT_LEVEL3,												// 0x03:interrupt level 3
	I2CM_INT_LEVEL4,												// 0x04:interrupt level 4
	I2CM_INT_LEVEL5,												// 0x05:interrupt level 5
	I2CM_INT_LEVEL6,												// 0x06:interrupt level 6
	I2CM_INT_LEVEL7,												// 0x07:interrupt level 7

	I2CM_INT_LEVELMAX
};

// I2C master initialize parameter.
#define	I2CM_NOISEREMOVE_OFF		I2CM_OFF						// noise remove off
#define	I2CM_NOISEREMOVE_ON			I2CM_ON							// noise remove on

// I2C master enable / disable.
#define	I2CM_CTL_DISABLE			I2CM_DISABLE					// I2C master disable
#define	I2CM_CTL_ENABLE				I2CM_ENABLE						//			  enable

// I2C master start/stop condition.
#define	I2CM_CONDITION_START		(STRT*I2CM_START)				// start condition
#define	I2CM_CONDITION_STOP			(STP*I2CM_STOP)					// stop  condition

// I2C master transmit status.
#define	I2CM_TXREG_EMPTY			0x00							// transmit register empty
#define	I2CM_TXREG_NOTEMPTY			0x01							// transmit register not empty
#define	I2CM_TX_IDLE				I2CM_IDLE						// transmit idle
#define	I2CM_TX_BUSY				I2CM_BUSY						// transmit busy

// I2C slave response.
#define	I2CM_SLAVE_ACK				I2CM_ACK						// response ACK
#define	I2CM_SLAVE_NAK				I2CM_ERROR						//			NAK

// I2C master receive status.
#define	I2CM_RX_IDLE				I2CM_IDLE						// receive idle
#define	I2CM_RX_BUSY				I2CM_BUSY						// receive busy
#define	I2CM_RXREG_EMPTY			I2CM_EMPTY						// receive register empty
#define	I2CM_RXREG_NOTEMPTY			I2CM_READY						// receive register not empty

// I2C master interrupt.
#define	I2CM_RXINT_DISABLE			(RINTE*I2CM_DISABLE)			// receive interrupt disable
#define	I2CM_RXINT_ENABLE			(RINTE*I2CM_ENABLE)				//					 enable
#define	I2CM_TXINT_DISABLE			(TINTE*I2CM_DISABLE)			// transmit interrupt disable
#define	I2CM_TXINT_ENABLE			(TINTE*I2CM_ENABLE)				//					  enable

// make slave address parameter.
#define	I2CM_ADDRESS_7BIT			0x00							// slave address mode :  7-bit
#define	I2CM_ADDRESS_10BIT			0x01							//					  : 10-bit
#define	I2CM_DIR_TX					0x0000							// select direction : transmit
#define	I2CM_DIR_RX					0x0001							//					: receive


/******************************************
 * Declarations of function prototype
 ******************************************/
extern short I2CM_init(unsigned short selectBit);
extern short I2CM_setComEnable(unsigned short selectBit);
extern short I2CM_genCondition(unsigned short selectBit);
extern unsigned short I2CM_checkTransmitReg(void);
extern void I2CM_setTransmitData(unsigned char data);
extern unsigned short I2CM_checkTransmitBusy(void);
extern unsigned short I2CM_getSlaveResponse(void);
extern short I2CM_setReceiveStart(unsigned short response);
extern unsigned short I2CM_checkReceiveBusy(void);
extern void I2CM_getReceiveData(unsigned char *data);
extern unsigned short I2CM_checkReceiveReg(void);
extern short I2CM_initInt(unsigned char intLevel);
extern short I2CM_controlInt(unsigned short selectBit);
extern short I2CM_transmitSlaveAddress(unsigned char selectBit, unsigned short dir, unsigned short *address);


#endif	// end of I2CM_API_H_
