/******************************************************************
 * lcd_api.h
 * 
 * LCD driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef LCD_API_H_
#define LCD_API_H_

#include <lcd.h>

/******************************************
 * definition of "define"
 ******************************************/

// LCD driver return code.
#define	LCD_SUCCESS					 0								// success
#define	LCD_INVALID_PARAMETER		-1								// invalid parameter
#define	LCD_FAILURE					-2								// failure

// LCD interrupt level.
enum {
	LCD_INT_LEVEL0 = 0x00,											// 0x00:interrupt level 0
	LCD_INT_LEVEL1,													// 0x01:interrupt level 1
	LCD_INT_LEVEL2,													// 0x02:interrupt level 2
	LCD_INT_LEVEL3,													// 0x03:interrupt level 3
	LCD_INT_LEVEL4,													// 0x04:interrupt level 4
	LCD_INT_LEVEL5,													// 0x05:interrupt level 5
	LCD_INT_LEVEL6,													// 0x06:interrupt level 6
	LCD_INT_LEVEL7,													// 0x07:interrupt level 7

	LCD_INT_LEVELMAX
};

// LCD SEG / COM No.
enum {
	LCD_SEG00 = 0,													// 00 : SEG00
	LCD_SEG01,														// 01 : SEG01
	LCD_SEG02,														// 02 : SEG02
	LCD_SEG03,														// 03 : SEG03
	LCD_SEG04,														// 04 : SEG04
	LCD_SEG05,														// 05 : SEG05
	LCD_SEG06,														// 06 : SEG06
	LCD_SEG07,														// 07 : SEG07
#ifndef	LCD_SEG_8
	LCD_SEG08,														// 08 : SEG08
	LCD_SEG09,														// 09 : SEG09
	LCD_SEG10,														// 10 : SEG10
	LCD_SEG11,														// 11 : SEG11
#ifndef	LCD_SEG_12
	LCD_SEG12,														// 12 : SEG12
	LCD_SEG13,														// 13 : SEG13
	LCD_SEG14,														// 14 : SEG14
	LCD_SEG15,														// 15 : SEG15
#ifndef	LCD_SEG_16
	LCD_SEG16,														// 16 : SEG16
	LCD_SEG17,														// 17 : SEG17
	LCD_SEG18,														// 18 : SEG18
	LCD_SEG19,														// 19 : SEG19
#ifndef	LCD_SEG_20
	LCD_SEG20,														// 20 : SEG20
	LCD_SEG21,														// 21 : SEG21
	LCD_SEG22,														// 22 : SEG22
	LCD_SEG23,														// 23 : SEG23
	LCD_SEG24,														// 24 : SEG24
	LCD_SEG25,														// 25 : SEG25
	LCD_SEG26,														// 26 : SEG26
	LCD_SEG27,														// 27 : SEG27
	LCD_SEG28,														// 28 : SEG28
	LCD_SEG29,														// 29 : SEG29
	LCD_SEG30,														// 30 : SEG30
	LCD_SEG31,														// 31 : SEG31
	LCD_SEG32,														// 32 : SEG32
	LCD_SEG33,														// 33 : SEG33
	LCD_SEG34,														// 34 : SEG34
	LCD_SEG35,														// 35 : SEG35
#ifndef	LCD_SEG_36
	LCD_SEG36,														// 36 : SEG36
	LCD_SEG37,														// 37 : SEG37
	LCD_SEG38,														// 38 : SEG38
	LCD_SEG39,														// 39 : SEG39
#ifndef	LCD_SEG_40
	LCD_SEG40,														// 40 : SEG40
	LCD_SEG41,														// 41 : SEG41
	LCD_SEG42,														// 42 : SEG42
	LCD_SEG43,														// 43 : SEG43
	LCD_SEG44,														// 44 : SEG44
	LCD_SEG45,														// 45 : SEG45
	LCD_SEG46,														// 46 : SEG46
	LCD_SEG47,														// 47 : SEG47
	LCD_SEG48,														// 48 : SEG48
	LCD_SEG49,														// 49 : SEG49
	LCD_SEG50,														// 50 : SEG50
	LCD_SEG51,														// 51 : SEG51
#ifndef	LCD_SEG_52
	LCD_SEG52,														// 52 : SEG52
	LCD_SEG53,														// 53 : SEG53
	LCD_SEG54,														// 54 : SEG54
	LCD_SEG55,														// 55 : SEG55
#endif	// end of LCD_SEG_52
#endif	// end of LCD_SEG_40
#endif	// end of LCD_SEG_36
#endif	// end of LCD_SEG_20
#endif	// end of LCD_SEG_16
#endif	// end of LCD_SEG_12
#endif	// end of LCD_SEG_8
	
	LCD_SEG_MAX
};

enum {
	LCD_COM00 = 0,													// 00 : COM00
	LCD_COM01,														// 01 : COM01
	LCD_COM02,														// 02 : COM02
	LCD_COM03,														// 03 : COM03
#ifndef	LCD_COM_4
	LCD_COM04,														// 04 : COM04
	LCD_COM05,														// 05 : COM05
	LCD_COM06,														// 06 : COM06
	LCD_COM07,														// 07 : COM07
#endif	// end of LCD_COM_4
	
	LCD_COM_MAX
};

// LCD initialize parameter.
#define	LCD_PROTECTMODE_OFF			LCD_OFF							// LCD heavy load protection mode : off
#define	LCD_PROTECTMODE_ON			LCD_ON							//								  : on
#define	LCD_POWERSELECT_1V			LCD_1V							// select power source : 1V
#define	LCD_POWERSELECT_2V			LCD_2V							//					   : 2V

enum {
	LCD_DUTY_STATIC = 0,											// 0x00 : select LCD duty : static
	LCD_DUTY_2,														// 0x01 : 				  : 1/2
	LCD_DUTY_3,														// 0x02 : 				  : 1/3
	LCD_DUTY_4,														// 0x03 : 				  : 1/4
	LCD_DUTY_8,														// 0x04 : 				  : 1/8
	
	LCD_DUTY_MAX
};

// LCD assignment control.
#define	LCD_SEGASIN_REVERSE			LCD_REVERSE						// segment output assignment : reverse
#define	LCD_SEGASIN_NORMAL			LCD_NORMAL						//							 : normal
#define	LCD_COMASIN_REVERSE			LCD_REVERSE						// common output assignment : reverse
#define	LCD_COMASIN_NORMAL			LCD_NORMAL						//							: normal

// LCD display control.
#define	LCD_DISPLAY_AREA0			LCD_AREA0						// display memory area 0
#define	LCD_DISPLAY_AREA1			LCD_AREA1						//					   1
#define	LCD_DISPREV_REVERSE			LCD_REVERSE						// display reverse
#define	LCD_DISPREV_NORMAL			LCD_NORMAL						//		   normal

enum {
	LCD_DISPLAY_OFF = 0,											// 0x00 : LCD display : display off
	LCD_DISPLAY_NORMAL,												// 0x01 : 			  : normal display
	LCD_DISPLAY_ALLON,												// 0x02 : 			  : all on
	LCD_DISPLAY_ALLOFF,												// 0x03 : 			  : all off
	
	LCD_DISPLAY_MAX
};

// LCD contrast adjustment.
enum {
	LCD_CONTRAST_0 = 0,												// 0x00 : LCD contrast adjustment 0
	LCD_CONTRAST_1,													// 0x01 : 						  1
	LCD_CONTRAST_2,													// 0x02 : 						  2
	LCD_CONTRAST_3,													// 0x03 : 						  3
	LCD_CONTRAST_4,													// 0x04 : 						  4
	LCD_CONTRAST_5,													// 0x05 : 						  5
	LCD_CONTRAST_6,													// 0x06 : 						  6
	LCD_CONTRAST_7,													// 0x07 : 						  7
	LCD_CONTRAST_8,													// 0x08 : 						  8
	LCD_CONTRAST_9,													// 0x09 : 						  9
	LCD_CONTRAST_A,													// 0x0A : 						  A
	LCD_CONTRAST_B,													// 0x0B : 						  B
	LCD_CONTRAST_C,													// 0x0C : 						  C
	LCD_CONTRAST_D,													// 0x0D : 						  D
	LCD_CONTRAST_E,													// 0x0E : 						  E
	LCD_CONTRAST_F,													// 0x0F : 						  F
	
	LCD_CONTRAST_MAX
};

// LCD display data.
#define	LCD_DOT_L					0x00							// display data : off
#define	LCD_DOT_H					0x01							//				: on

// LCD interrupt.
#define	LCD_INT_DISABLE				LCD_DISABLE						// frame signal interrupt disable
#define	LCD_INT_ENABLE				LCD_ENABLE						//						  enable

// LCD interrupt flag.
#define	LCD_INT_RESET				LCD_RESET						// frame signal interrupt reset

#define	LCD_INT_NOTOCCURRED			LCD_NOTOCCURRED					// frame signal interrupt not occurred
#define	LCD_INT_OCCURRED			LCD_OCCURRED					//						  occurred


/******************************************
 * Declarations of function prototype
 ******************************************/
extern short LCD_initPower(unsigned char selectMode, unsigned char selectVoltage);
extern short LCD_init(unsigned char selectContrast, unsigned char selectDuty);
extern short LCD_setSEGAssignment(unsigned char selectBit);
extern short LCD_setCOMAssignment(unsigned char selectBit);
extern short LCD_setDisplayArea(unsigned char selectBit);
extern short LCD_setDisplayReverse(unsigned char selectBit);
extern short LCD_controlDisplay(unsigned char selectBit);
extern short LCD_setContrast(unsigned char selectBit);
extern short LCD_display1Seg(unsigned char seg, unsigned char com, unsigned char data);
extern short LCD_initInt(unsigned char intLevel);
extern short LCD_controlInt(unsigned char selectBit);
extern void LCD_resetIntFlag(void);
extern void LCD_checkIntFlag(unsigned char *flag);


#endif	// end of LCD_API_H_
