/******************************************************************
 * misc_api.h
 * 
 * MISC driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef MISC_API_H_
#define MISC_API_H_

#include <misc.h>

/******************************************
 * definition of "define"
 ******************************************/

// MISC driver return code.
#define	MISC_SUCCESS				 0								// success
#define	MISC_INVALID_PARAMETER		-1								// invalid parameter
#define	MISC_FAILURE				-2								// failure

// FLASHC read access cycle.
enum {
 	MISC_READ_CYCLE2 = 0,											// 0x00 : read access 2 cycles
 	MISC_READ_CYCLE3,												// 0x01 : 			  3 cycles
 	MISC_READ_CYCLE4,												// 0x02 : 			  4 cycles
 	MISC_READ_CYCLE5,												// 0x03 : 			  5 cycles
 	MISC_READ_CYCLE1,												// 0x04 : 			  1 cycles
	
	MISC_READ_MAX
};

// OSC1 peripheral control in debug mode.
#define	MISC_OSC1PERIPHERAL_STOP	MISC_STOP						// OSC1 control : stop
#define	MISC_OSC1PERIPHERAL_RUN		MISC_RUN						//				: run

// MISC register write protect.
#define	MISC_WRITEPROTECT_ON		PROTECT_ON						// write protect on
#define	MISC_WRITEPROTECT_OFF		PROTECT_OFF						//				 off

// IRAM size select.
#define	MISC_DEBUGADDRESS_F			MISC_ADDRESS_F					// select debug base address 0xfffc00
#define	MISC_DEBUGADDRESS_0			MISC_ADDRESS_0					//							 0x000000

enum {
	MISC_IRAMSIZE_12KB = 0,											// 0x00 : select IRAM size : 12KB
	MISC_IRAMSIZE_8KB,												// 0x01 : 				   :  8KB
	MISC_IRAMSIZE_4KB,												// 0x02 : 				   :  4KB
	MISC_IRAMSIZE_2KB,												// 0x03 : 				   :  2KB
#ifndef	S1C17602
	MISC_IRAMSIZE_1KB,												// 0x04 : 				   :  1KB
	MISC_IRAMSIZE_512B,												// 0x05 : 				   :  512B
#endif
	
	MISC_IRAMSIZE_MAX
};

// PSR register status.
enum {
	MISC_PSRINT_LEVEL0 = 0,											// 0x00 : interrup level 0
	MISC_PSRINT_LEVEL1,												// 0x01 : 				 1
	MISC_PSRINT_LEVEL2,												// 0x02 : 				 2
	MISC_PSRINT_LEVEL3,												// 0x03 : 				 3
	MISC_PSRINT_LEVEL4,												// 0x04 : 				 4
	MISC_PSRINT_LEVEL5,												// 0x05 : 				 5
	MISC_PSRINT_LEVEL6,												// 0x06 : 				 6
	MISC_PSRINT_LEVEL7,												// 0x07 : 				 7
	
	MISC_PSRINT_MAX
};

#define	MISC_PSRIE_DISABLE			(PSRIE*MISC_DISABLE)			// interrupt disable
#define	MISC_PSRIE_ENABLE			(PSRIE*MISC_ENABLE)				//			 enable
#define	MISC_CFLAG_CLEARED			(PSRC*MISC_CLEARD)				// carry (C) flag : 0
#define	MISC_CFLAG_SET				(PSRC*MISC_SET)					//				  : 1
#define	MISC_VFLAG_CLEARED			(PSRV*MISC_CLEARD)				// overflow (V) flag : 0
#define	MISC_VFLAG_SET				(PSRV*MISC_SET)					//					 : 1
#define	MISC_ZFLAG_CLEARED			(PSRZ*MISC_CLEARD)				// zero (Z) flag : 0
#define	MISC_ZFLAG_SET				(PSRZ*MISC_SET)					//				 : 1
#define	MISC_NFLAG_CLEARED			(PSRN*MISC_CLEARD)				// negative (N) flag : 0
#define	MISC_NFLAG_SET				(PSRN*MISC_SET)					//					 : 1


/******************************************
 * Declarations of function prototype
 ******************************************/
extern short MISC_setFlashReadAccessCycle(unsigned short selectBit);
extern short MISC_setOSC1PeripheralControl(unsigned short selectBit);
extern void MISC_controlWriteProtect(unsigned short selectBit);
extern short MISC_setIRAMSize(unsigned short selectAddress, unsigned short selectSize);
extern short MISC_setTTBR(unsigned short ttbrL, unsigned short ttbrH);
extern void MISC_getPSR(unsigned short *data);


#endif	// end of MISC_API_H_
