/******************************************************************
 * mux_api.h
 * 
 * MUX driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef MUX_API_H_
#define MUX_API_H_

#include <mux.h>

/******************************************
 * definition of "define"
 ******************************************/

// MUX driver return code.
#define	MUX_SUCCESS					 0								// success
#define	MUX_INVALID_PARAMETER		-1								// invalid parameter
#define	MUX_FAILURE					-2								// failure

// MUX on / off select.
#define	MUX_OFF						0								// port select
#define	MUX_ON						1								// function select

// set ADC port.
#define	MUX_ADTRG_OFF				0x00							// select external trigger off
#define	MUX_ADTRG_ON				0x01							//						   on

// set SPI port.
enum {
	MUX_SPI_SPICLK = 0,												// 0x00 : SPICLK
	MUX_SPI_SDO,													// 0x01 : SDO
	MUX_SPI_SDI,													// 0x02 : SDI
	MUX_SPI_SPISS,													// 0x03 : SPISS

	MUX_SPI_PORTMAX
};

// set UART port.
enum {
	MUX_UART_SOUT = 0,												// 0x00 : SOUT
	MUX_UART_SIN,													// 0x01 : SIN
	MUX_UART_SCLK,													// 0x02 : SCLK

	MUX_UART_PORTMAX
};

#define	MUX_UART_CLK_INTERNAL		0x00							// select input clock : internal
#define	MUX_UART_CLK_EXTERNAL		0x01							//					  : external

// set RFC port.
enum {
	MUX_RFC_RFIN = 0,												// 0x00 : RFIN
	MUX_RFC_REF,													// 0x01 : REF
	MUX_RFC_SENA,													// 0x02 : SENA
	MUX_RFC_SENB,													// 0x03 : SENB
	MUX_RFC_RFCLK,													// 0x04 : RFCLKO

	MUX_RFC_PORTMAX
};

#define	MUX_RFIN_OFF				0x00							// select external clock off
#define	MUX_RFIN_ON					0x01							//						 on
#define	MUX_REF_OFF					0x00							// select reference off
#define	MUX_REF_ON					0x01							//					on
#define	MUX_SENA_OFF				0x00							// select sensor A off
#define	MUX_SENA_ON					0x01							//				   on
#define	MUX_SENB_OFF				0x00							// select sensor B off
#define	MUX_SENB_ON					0x01							//				   on
#define	MUX_RFCLK_OFF				0x00							// select RFCLK output off
#define	MUX_RFCLK_ON				0x01							//					   on

// set I2C master port.
enum {
	MUX_I2CM_0 = 0,													// 0x00 : select number 0
	MUX_I2CM_1,														// 0x01 : 				1

	MUX_I2CM_MAX
};

enum {
	MUX_I2CM_SCL = 0,												// 0x00 : SCL
	MUX_I2CM_SDA,													// 0x01 : SDA

	MUX_I2CM_PORTMAX
};

#define	MUX_I2CM_0					0x00							// select number 0
#define	MUX_I2CM_1					0x01							//				 1

// set OSC port.
#define	MUX_FOUT1_OFF				0x00							// select FOUT1 off
#define	MUX_FOUT1_ON				0x01							//				on
#define	MUX_FOUTH_OFF				0x00							// select FOUTH off
#define	MUX_FOUTH_ON				0x01							//				on

// set PWM timer port.
enum {
	MUX_T16E_T3 = 0,												// 0x00 : TOUT3
	MUX_T16E_TN3,													// 0x01 : TOUTN3

	MUX_T16E_PORTMAX
};

/******************************************
 * definition of "struct"
 ******************************************/

// select RFC use port.
struct tag_MUX_USE_RFCPORT;
typedef struct tag_MUX_USE_RFCPORT {
	unsigned char	useRfin;										// select external clock
	unsigned char	useRef;											// select reference
	unsigned char	useSenA;										// select sensor A
	unsigned char	useSenB;										// select sensor B
	unsigned char	useRfclk;										// select RFCLK output
} MUX_USE_RFCPORT;


/******************************************
 * Declarations of function prototype
 ******************************************/
#ifdef	PE_PORT
extern void MUX_init(void);
#endif	// end of PE_PORT
#ifdef	PE_REMC
extern short MUX_setREMCport(unsigned char sw);
#endif	// end of PE_REMC
#ifdef	PE_ADC
extern short MUX_setADCport(unsigned char use, unsigned short startCh, unsigned short endCh, unsigned char sw);
#endif	// end of PE_ADC
#ifdef	PE_SPI
extern short MUX_setSPIport(unsigned char chNo, unsigned char sw);
#endif	// end of PE_SPI
#ifdef	PE_UART
extern short MUX_setUARTport(unsigned char chNo, unsigned char inputClk, unsigned char sw);
#endif	// end of PE_UART
#ifdef	PE_RFC
extern short MUX_setRFCport(unsigned char chNo, MUX_USE_RFCPORT *use, unsigned char sw);
#endif	// end of PE_RFC
#ifdef	PE_I2CM
extern short MUX_setI2CMport(unsigned char selectNo, unsigned char sw);
#endif	// end of PE_I2CM
#ifdef	PE_I2CS
extern short MUX_setI2CSport(unsigned char sw);
#endif	// end of PE_I2CS
#ifdef	PE_OSC
extern short MUX_setOSCport(unsigned char useFout1, unsigned char useFouth, unsigned char sw);
#endif	// end of PE_OSC
#ifdef	PE_T16E
extern short MUX_setT16Eport(unsigned char chNo, unsigned char sw);
#endif	// end of PE_T16E
#ifdef	PE_LCD
extern short MUX_setLCDport(unsigned char sw);
#endif	// end of PE_LCD
#ifdef	PE_T8OSC1
extern short MUX_setT8OSC1port(unsigned char sw);
#endif	// end of PE_T8OSC1
extern short MUX_setDBGport(unsigned char sw);
#ifdef	PE_T16
extern short MUX_setT16port(unsigned char chNo, unsigned char sw);
#endif	// end of PE_T16


#endif	// end of MUX_API_H_
