/******************************************************************
 * osc_api.h
 * 
 * OSC driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef OSC_API_H_
#define OSC_API_H_

#include <osc.h>

/******************************************
 * definition of "define"
 ******************************************/

// OSC driver return code.
#define OSC_SUCCESS					 0								// success
#define OSC_INVALID_PARAMETER		-1								// invalid parameter
#define OSC_FAILURE					-2								// failure

// OSC clock control.
#define OSC_SELHSCLK_IOSC			SRC_IOSC						// select High-speed clock : IOSC
#define OSC_SELHSCLK_OSC3			SRC_OSC3						//						   : OSC3
#define OSC_SELCLKSRC_HSCLK			SRC_HSCLK						// select system clock source : HSCLK
#define OSC_SELCLKSRC_OSC1			SRC_OSC1						//							  : OSC1

enum {
	OSC_SELIOSC_64 = 0,												// 0x00 : select IOSC wait cycle : 64 cycle
	OSC_SELIOSC_32,													// 0x01 :						 : 32 cycle
	OSC_SELIOSC_16,													// 0x02 :						 : 16 cycle
	OSC_SELIOSC_8,													// 0x03 :						 :  8 cycle
	
	OSC_SELIOSC_MAX
};

enum {
	OSC_SELOSC3_1024  = 0,											// 0x00 : select OSC3 wait cycle : 1024 cycle 
	OSC_SELOSC3_512,												// 0x01 :						 :  512 cycle 
	OSC_SELOSC3_256,												// 0x02 :						 :  256 cycle 
	OSC_SELOSC3_128,												// 0x03 :						 :  128 cycle 
	
	OSC_SELOSC3_MAX
};

// OSC oscillation control.
#define OSC_IOSC_DISABLE			(IOSCEN*OSC_DISABLE)			// IOSC disable
#define OSC_IOSC_ENABLE				(IOSCEN*OSC_ENABLE)				//		enable
#define OSC_OSC1_DISABLE			(OSC1EN*OSC_DISABLE)			// OSC1 disable
#define OSC_OSC1_ENABLE				(OSC1EN*OSC_ENABLE)				//		enable
#define OSC_OSC3_DISABLE			(OSC3EN*OSC_DISABLE)			// OSC3 disable
#define OSC_OSC3_ENABLE				(OSC3EN*OSC_ENABLE)				//		enable

// OSC noise filter control.
#define OSC_NOISE_RESET_DISABLE		(RSTFE*OSC_DISABLE)				// reset noise filter disable
#define OSC_NOISE_RESET_ENABLE		(RSTFE*OSC_ENABLE)				//					  enable
#define OSC_NOISE_NMI_DISABLE		(NMIFE*OSC_DISABLE)				// NMI noise filter disable
#define OSC_NOISE_NMI_ENABLE		(NMIFE*OSC_ENABLE)				//					enable

// LCD clock control.
#define OSC_LCDCLK_HSCLK			LCKSRC_HSCLK					// select LCD clock source : HSCLK
#define OSC_LCDCLK_OSC1				LCKSRC_OSC1						//						   : OSC1

// LCD clock source the case of HSCLK
enum {
	OSC_LCDRATIO_32 = 0,											// 0x00 : select LCD clock division ratio : HSCLK1/32
	OSC_LCDRATIO_64,												// 0x01 :								  : HSCLK1/64
	OSC_LCDRATIO_128,												// 0x02 :								  : HSCLK1/128
	OSC_LCDRATIO_256,												// 0x03 :								  : HSCLK1/256
	OSC_LCDRATIO_512,												// 0x04 :								  : HSCLK1/512
	
	OSC_LCDRATIO_MAX
};

#define OSC_LCDCLK_DISABLE			OSC_DISABLE						// LCD clock disable
#define OSC_LCDCLK_ENABLE			OSC_ENABLE						//			 enable

// FOUT clock control.
enum {
	OSC_FOUTCLK_1 = 0,												// 0x00 : select FOUTH clock division ratio : HSCLK1/1
	OSC_FOUTCLK_2,													// 0x01 :									: HSCLK1/2
	OSC_FOUTCLK_4,													// 0x02 :									: HSCLK1/4
	
	OSC_FOUTCLK_MAX
};

#define OSC_FOUTH_DISABLE			(FOUTHE*OSC_DISABLE)			// FOUTH output disable
#define OSC_FOUTH_ENABLE			(FOUTHE*OSC_ENABLE)				//				enable
#define OSC_FOUT1_DISABLE			(FOUT1E*OSC_DISABLE)			// FOUT1 output disable
#define OSC_FOUT1_ENABLE			(FOUT1E*OSC_ENABLE)				//				enable

// T8OSC1 clock control.
enum {
	OSC_T8OSC1CLK_1 = 0,											// 0x00 : select T8SC1 clock divisio ratio : HSCLK1/1
	OSC_T8OSC1CLK_2,												// 0x01 :								   : HSCLK1/2
	OSC_T8OSC1CLK_4,												// 0x02 :								   : HSCLK1/4
	OSC_T8OSC1CLK_8,												// 0x03 :								   : HSCLK1/8
	OSC_T8OSC1CLK_16,												// 0x04 :								   : HSCLK1/16
	OSC_T8OSC1CLK_32,												// 0x05 :								   : HSCLK1/32
	
	OSC_T8OSC1CLK_MAX
};

#define OSC_T8OSC1_DISABLE			(T8O1CE*OSC_DISABLE)			// T8OSC1 clock output disable
#define OSC_T8OSC1_ENABLE			(T8O1CE*OSC_ENABLE)				//					   enable

// SVD clock control.
#define OSC_SVDCLK_HSCLK			SVDSRC_HSCLK					// select SVD clock source : HSCLK1/512
#define OSC_SVDCLK_OSC1				SVDSRC_OSC1						//						   : OSC1

#define OSC_SVD_DISABLE				OSC_DISABLE						// SVD clock disable
#define OSC_SVD_ENABLE				OSC_ENABLE						// 			 enable

// RFC clock control.
#define OSC_RFCCLK_HSCLK			RFTCKSRC_HSCLK					// select RFC TC clock source : HSCLK
#define OSC_RFCCLK_OSC1				RFTCKSRC_OSC1					//							  : OSC1

// RFC TC clock source the case of HSCLK
enum {
	OSC_RFCRATIO_1 = 0,												// 0x00 : select RFC TC clock division ratio : HSCLK1/1
	OSC_RFCRATIO_2,													// 0x01 :									 : HSCLK1/2
	OSC_RFCRATIO_4,													// 0x02 :									 : HSCLK1/4
	OSC_RFCRATIO_8,													// 0x03 :									 : HSCLK1/8
	
	OSC_RFCRATIO_MAX
};

#define OSC_RFCCLK_DISABLE			OSC_DISABLE						// RFC TC clock disable
#define OSC_RFCCLK_ENABLE			OSC_ENABLE						//				enable


/******************************************
 * Declarations of function prototype
 ******************************************/
extern short OSC_setClockSource(unsigned char selectHSCLK, unsigned char selectCLKSRC);
extern short OSC_setWaitCycle(unsigned char selectIOSC, unsigned char selectOSC3);
extern short OSC_controlOscillation(unsigned char selectBit);
extern short OSC_setNoiseFilter(unsigned char selectBit);
extern short OSC_setLCDClock(unsigned char selectOsc, unsigned char selectRatio);
extern short OSC_controlLCDClock(unsigned char selectBit);
extern short OSC_setFOUTHDivision(unsigned char selectBit);
extern short OSC_controlFOUT(unsigned char selectBit);
extern short OSC_setT8OSC1Division(unsigned char selectBit);
extern short OSC_controlT8OSC1(unsigned char selectBit);
extern short OSC_setSVDClock(unsigned char selectBit);
extern short OSC_controlSVD(unsigned char selectBit);
extern short OSC_setRFCClock(unsigned char selectOsc, unsigned char selectRatio);
extern short OSC_controlRFC(unsigned char selectBit);


#endif	// end of OSC_API_H_
