/******************************************************************
 * port_api.h
 * 
 * port driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef PORT_API_H_
#define PORT_API_H_

#include <port.h>

/******************************************
 * definition of "define"
 ******************************************/

// Port driver return code.
#define	PORT_SUCCESS				 0								// success
#define	PORT_INVALID_PARAMETER		-1								// invalid parameter

// port interrupt level.
enum {
	PORT_INT_LEVEL0 = 0x00,											// 0x00:interrupt level 0
	PORT_INT_LEVEL1,												// 0x01:interrupt level 1
	PORT_INT_LEVEL2,												// 0x02:interrupt level 2
	PORT_INT_LEVEL3,												// 0x03:interrupt level 3
	PORT_INT_LEVEL4,												// 0x04:interrupt level 4
	PORT_INT_LEVEL5,												// 0x05:interrupt level 5
	PORT_INT_LEVEL6,												// 0x06:interrupt level 6
	PORT_INT_LEVEL7,												// 0x07:interrupt level 7

	PORT_INT_LEVELMAX
};

// Port number.
enum {
	PORT_NO_P0 = 0,													// 0x00 : P0 port
	PORT_NO_P1,														// 0x01 : P1 port
	PORT_NO_P2,														// 0x02 : P2 port
#ifndef	PORT_MAX_P2
	PORT_NO_P3,														// 0x03 : P3 port
#ifndef	PORT_MAX_P3
	PORT_NO_P4,														// 0x04 : P4 port
#endif	// end of PORT_MAX_P3
#endif	// end of PORT_MAX_P2
	
	PORT_NO_MAX
};

#define	PORT_BIT_X0					BIT_PX0							// Px0 port
#define	PORT_BIT_X1					BIT_PX1							// Px1 port
#define	PORT_BIT_X2					BIT_PX2							// Px2 port
#define	PORT_BIT_X3					BIT_PX3							// Px3 port
#define	PORT_BIT_X4					BIT_PX4							// Px4 port
#define	PORT_BIT_X5					BIT_PX5							// Px5 port
#define	PORT_BIT_X6					BIT_PX6							// Px6 port
#define	PORT_BIT_X7					BIT_PX7							// Px7 port

// port control.
#define	PORT_PX0_DISABLE			(PORT_BIT_X0*PORT_DISABLE)		// Px0 disable
#define	PORT_PX0_ENABLE				(PORT_BIT_X0*PORT_ENABLE)		// Px0 enable
#define	PORT_PX1_DISABLE			(PORT_BIT_X1*PORT_DISABLE)		// Px1 disable
#define	PORT_PX1_ENABLE				(PORT_BIT_X1*PORT_ENABLE)		// Px1 enable
#define	PORT_PX2_DISABLE			(PORT_BIT_X2*PORT_DISABLE)		// Px2 disable
#define	PORT_PX2_ENABLE				(PORT_BIT_X2*PORT_ENABLE)		// Px2 enable
#define	PORT_PX3_DISABLE			(PORT_BIT_X3*PORT_DISABLE)		// Px3 disable
#define	PORT_PX3_ENABLE				(PORT_BIT_X3*PORT_ENABLE)		// Px3 enable
#define	PORT_PX4_DISABLE			(PORT_BIT_X4*PORT_DISABLE)		// Px4 disable
#define	PORT_PX4_ENABLE				(PORT_BIT_X4*PORT_ENABLE)		// Px4 enable
#define	PORT_PX5_DISABLE			(PORT_BIT_X5*PORT_DISABLE)		// Px5 disable
#define	PORT_PX5_ENABLE				(PORT_BIT_X5*PORT_ENABLE)		// Px5 enable
#define	PORT_PX6_DISABLE			(PORT_BIT_X6*PORT_DISABLE)		// Px6 disable
#define	PORT_PX6_ENABLE				(PORT_BIT_X6*PORT_ENABLE)		// Px6 enable
#define	PORT_PX7_DISABLE			(PORT_BIT_X7*PORT_DISABLE)		// Px7 disable
#define	PORT_PX7_ENABLE				(PORT_BIT_X7*PORT_ENABLE)		// Px7 enable

// port interrupt flag.
#define	PORT_PX0_RESET				(PORT_BIT_X0*PORT_RESET)		// Px0 flag reset
#define	PORT_PX1_RESET				(PORT_BIT_X1*PORT_RESET)		// Px1 flag reset
#define	PORT_PX2_RESET				(PORT_BIT_X2*PORT_RESET)		// Px2 flag reset
#define	PORT_PX3_RESET				(PORT_BIT_X3*PORT_RESET)		// Px3 flag reset
#define	PORT_PX4_RESET				(PORT_BIT_X4*PORT_RESET)		// Px4 flag reset
#define	PORT_PX5_RESET				(PORT_BIT_X5*PORT_RESET)		// Px5 flag reset
#define	PORT_PX6_RESET				(PORT_BIT_X6*PORT_RESET)		// Px6 flag reset
#define	PORT_PX7_RESET				(PORT_BIT_X7*PORT_RESET)		// Px7 flag reset

#define	PORT_PX0_NOTOCCURRED		(PORT_BIT_X0*PORT_NOTOCCURRED)	// Px0 not occurred
#define	PORT_PX0_OCCURRED			(PORT_BIT_X0*PORT_OCCURRED)		// Px0 occurred
#define	PORT_PX1_NOTOCCURRED		(PORT_BIT_X1*PORT_NOTOCCURRED)	// Px1 not occurred
#define	PORT_PX1_OCCURRED			(PORT_BIT_X1*PORT_OCCURRED)		// Px1 occurred
#define	PORT_PX2_NOTOCCURRED		(PORT_BIT_X2*PORT_NOTOCCURRED)	// Px2 not occurred
#define	PORT_PX2_OCCURRED			(PORT_BIT_X2*PORT_OCCURRED)		// Px2 occurred
#define	PORT_PX3_NOTOCCURRED		(PORT_BIT_X3*PORT_NOTOCCURRED)	// Px3 not occurred
#define	PORT_PX3_OCCURRED			(PORT_BIT_X3*PORT_OCCURRED)		// Px3 occurred
#define	PORT_PX4_NOTOCCURRED		(PORT_BIT_X4*PORT_NOTOCCURRED)	// Px4 not occurred
#define	PORT_PX4_OCCURRED			(PORT_BIT_X4*PORT_OCCURRED)		// Px4 occurred
#define	PORT_PX5_NOTOCCURRED		(PORT_BIT_X5*PORT_NOTOCCURRED)	// Px5 not occurred
#define	PORT_PX5_OCCURRED			(PORT_BIT_X5*PORT_OCCURRED)		// Px5 occurred
#define	PORT_PX6_NOTOCCURRED		(PORT_BIT_X6*PORT_NOTOCCURRED)	// Px6 not occurred
#define	PORT_PX6_OCCURRED			(PORT_BIT_X6*PORT_OCCURRED)		// Px6 occurred
#define	PORT_PX7_NOTOCCURRED		(PORT_BIT_X7*PORT_NOTOCCURRED)	// Px7 not occurred
#define	PORT_PX7_OCCURRED			(PORT_BIT_X7*PORT_OCCURRED)		// Px7 occurred

// port chattering control.
enum {
	PORT_CHATNO_P030 = 0,											// 0x00 : P00 - P03
	PORT_CHATNO_P074,												// 0x01 : P04 - P07
	PORT_CHATNO_P130,												// 0x02 : P10 - P13
	PORT_CHATNO_P174,												// 0x03 : P14 - P17
	
	PORT_CHAT_MAX
};

// chattering filter time
enum {
	PORT_CHATTIME_NONE = 0x00,										// 0x00:none
	PORT_CHATTIME_256,												// 0x01:256/fPCLK
	PORT_CHATTIME_512,												// 0x02:512/fPCLK
	PORT_CHATTIME_1024,												// 0x03:1024/fPCLK
	PORT_CHATTIME_2048,												// 0x04:2048/fPCLK
	PORT_CHATTIME_4096,												// 0x05:4096/fPCLK
	PORT_CHATTIME_8192,												// 0x06:8192/fPCLK
	PORT_CHATTIME_16384,											// 0x07:16384/fPCLK

	PORT_CHATTIME_MAX		
};


/******************************************
 * Declarations of function prototype
 ******************************************/
extern void PORT_init(void);
extern short PORT_getInputData(unsigned char portNo, unsigned char *data);
extern short PORT_setOutputData(unsigned char portNo, unsigned char data);
extern short PORT_controlInput(unsigned char portNo, unsigned char selectBit);
extern short PORT_controlOutput(unsigned char portNo, unsigned char selectBit);
extern short PORT_controlPullup(unsigned char portNo, unsigned char selectBit);
extern short PORT_controlSchmittTrigger(unsigned char portNo, unsigned char selectBit);
extern short PORT_initInt(unsigned char portNo, unsigned char intLevel);
extern short PORT_controlInt(unsigned char portNo, unsigned char selectBit);
extern short PORT_setIntEdge(unsigned char portNo, unsigned char selectBit);
extern short PORT_resetIntFlag(unsigned char portNo, unsigned char selectBit);
extern short PORT_checkIntFlag(unsigned char portNo, unsigned char *flag);
extern short PORT_setChatteringFilter(unsigned char portNo, unsigned char selectBit);


#endif	// end of PORT_API_H_
