/******************************************************************
 * remc_api.h
 * 
 * REMC driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef REMC_API_H_
#define REMC_API_H_

#include <remc.h>

/******************************************
 * definition of "define"
 ******************************************/

// REMC driver return code.
#define	REMC_SUCCESS				 0								// success
#define	REMC_INVALID_PARAMETER		-1								// invalid parameter
#define	REMC_FAILURE				-2								// failure

// REMC interrupt level.
enum {
	REMC_INT_LEVEL0 = 0x00,											// 0x00:interrupt level 0
	REMC_INT_LEVEL1,												// 0x01:interrupt level 1
	REMC_INT_LEVEL2,												// 0x02:interrupt level 2
	REMC_INT_LEVEL3,												// 0x03:interrupt level 3
	REMC_INT_LEVEL4,												// 0x04:interrupt level 4
	REMC_INT_LEVEL5,												// 0x05:interrupt level 5
	REMC_INT_LEVEL6,												// 0x06:interrupt level 6
	REMC_INT_LEVEL7,												// 0x07:interrupt level 7

	REMC_INT_LEVELMAX
};

// REMC carrier generator / length counter clock.
enum {
	REMC_CLK1 = 0,													// 0x00 : select clock : PCLK1/1
	REMC_CLK2,														// 0x01 : 			   : PCLK1/2
	REMC_CLK4,														// 0x02 : 			   : PCLK1/4
	REMC_CLK8,														// 0x03 : 			   : PCLK1/8
	REMC_CLK16,														// 0x04 : 			   : PCLK1/16
	REMC_CLK32,														// 0x05 : 			   : PCLK1/32
	REMC_CLK64,														// 0x06 : 			   : PCLK1/64
	REMC_CLK128,													// 0x07 : 			   : PCLK1/128
	REMC_CLK256,													// 0x08 : 			   : PCLK1/256
	REMC_CLK512,													// 0x09 : 			   : PCLK1/512
	REMC_CLK1024,													// 0x0a : 			   : PCLK1/1024
	REMC_CLK2048,													// 0x0b : 			   : PCLK1/2048
	REMC_CLK4096,													// 0x0c : 			   : PCLK1/4096
	REMC_CLK8192,													// 0x0d : 			   : PCLK1/8192
	REMC_CLK16384,													// 0x0e : 			   : PCLK1/16384
	
	REMC_CLK_MAX
};

// REMC enable / disable.
#define	REMC_TRANSMIT				REMC_TX							// select REMC mode transmit
#define	REMC_RECEIVE				REMC_RX							//					receive
#define	REMC_DISABLE				REMC_BIT_DISABLE				// REMC disable
#define	REMC_ENABLE					REMC_BIT_ENABLE					//		enable

// transmit / receive data.
#define	REMC_DATA_L					REMC_L							// data L
#define	REMC_DATA_H					REMC_H							//		H

// REMC interrupt.
#define	REMC_FALLINGINT_DISABLE		(REMFIE*REMC_BIT_DISABLE)		// falling edge interrupt disable
#define	REMC_FALLINGINT_ENABLE		(REMFIE*REMC_BIT_ENABLE)		//						  enable
#define	REMC_RISINGINT_DISABLE		(REMRIE*REMC_BIT_DISABLE)		// rising edge interrupt disable
#define	REMC_RISINGINT_ENABLE		(REMRIE*REMC_BIT_ENABLE)		//						 enable
#define	REMC_UDFINT_DISABLE			(REMUIE*REMC_BIT_DISABLE)		// underflow interrupt disable
#define	REMC_UDFINT_ENABLE			(REMUIE*REMC_BIT_ENABLE)		//					   enable

// REMC interrupt flag.
#define	REMC_FALLINGINT_RESET		(REMFIF*REMC_RESET)				// falling edge flag reset
#define	REMC_RISINGINT_RESET		(REMRIF*REMC_RESET)				// rising edge flag reset
#define	REMC_UDFINT_RESET			(REMUIF*REMC_RESET)				// underflow flag reset

#define	REMC_FALLINGINT_NOTOCCURRED	(REMFIF*REMC_NOTOCCURRED)		// falling edge interrupt not occurred
#define	REMC_FALLINGINT_OCCURRED	(REMFIF*REMC_OCCURRED)			//						  occurred
#define	REMC_RISINGINT_NOTOCCURRED	(REMRIF*REMC_NOTOCCURRED)		// rising edge interrupt not occurred
#define	REMC_RISINGINT_OCCURRED		(REMRIF*REMC_OCCURRED)			//						 occurred
#define	REMC_UDFINT_NOTOCCURRED		(REMUIF*REMC_NOTOCCURRED)		// underflow interrupt not occurred
#define	REMC_UDFINT_OCCURRED		(REMUIF*REMC_OCCURRED)			//					   occurred


/******************************************
 * definition of "struct"
 ******************************************/

// REMC initialize parameter.
struct tag_REMC_INIT_PARAM;
typedef struct tag_REMC_INIT_PARAM {
	unsigned short	selectMode;										// select REMC mode
	unsigned short	selectCarrier;									// select carrier generator clock
	unsigned short	selectLength;									// select length counter clock
	unsigned short	carrireL;										// L carrier length
	unsigned short	carrireH;										// H carrier length
} REMC_INIT_PARAM;


/******************************************
 * Declarations of function prototype
 ******************************************/
extern short REMC_init(REMC_INIT_PARAM *param);
extern short REMC_setEnable(unsigned short selectMode, unsigned short selectBit);
extern short REMC_setTransmitData(unsigned short data, unsigned short length);
extern void REMC_setReceiveLength(void);
extern void REMC_getReceiveData(unsigned short *data);
extern void REMC_calcReceiveDataPulse(unsigned short *data);
extern short REMC_initInt(unsigned char intLevel);
extern short REMC_controlInt(unsigned short selectBit);
extern short REMC_resetIntFlag(unsigned short selectBit);
extern void REMC_checkIntFlag(unsigned short *flag);


#endif	// end of REMC_API_H_
