/******************************************************************
 * ct.h
 * 
 * clock timer driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef CT_H_
#define CT_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct swt_ctlBitF {
	unsigned int	ctrun	: 1;
	unsigned int			: 3;
	unsigned int	ctrst	: 1;
	unsigned int			: 3;
};

struct swt_imskBitF {
	unsigned int	ctie1	: 1;
	unsigned int	ctie2	: 1;
	unsigned int	ctie8	: 1;
	unsigned int	ctie32	: 1;
	unsigned int			: 4;
};

struct swt_iflgBitF {
	unsigned int	ctif1	: 1;
	unsigned int	ctif2	: 1;
	unsigned int	ctif8	: 1;
	unsigned int	ctif32	: 1;
	unsigned int			: 4;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	CT_BASE_ADDR						(BASE_ADDR+CT_OFFSET)


/***********************************************
 ****** The Definition of ClockTimer ***********
 ****** [CT]                         ***********
 ***********************************************/
// Clock Timer Control Register
#define	R08_CT_CTL							(volatile unsigned char *)(unsigned long)(CT_BASE_ADDR+0x00)
	#define	CTRST_SFT							4
	#define	CTRUN_SFT							0
	#define	CTRST								BIT(0x01, CTRST_SFT)		// Clock Timer Reset
		#define	CT_INVALID							0x00						// invalid
		#define	CT_RESET							0x01						// reset
	#define	CTRUN								BIT(0x01, CTRUN_SFT)		// Clock Timer Run/Stop Control
		#define	CT_STOP								0x00						// stop
		#define	CT_RUN								0x01						// run

#ifdef	BIT_FIELD
#define CT_CTL								*(volatile unsigned char *)(BASE_ADDR+0x1000)
#define BF_CT_CTL							(*(volatile struct swt_ctlBitF *)(BASE_ADDR+0x1000))
	#define CT_CTL_CTRST						BF_CT_CTL.ctrst				// Clock timer reset
	#define CT_CTL_CTRUN						BF_CT_CTL.ctrun				// Clock timer run/stop control
#endif	// end of BIT_FIELD


// Clock Timer Counter Register
#define	R08_CT_CNT							(volatile unsigned char *)(unsigned long)(CT_BASE_ADDR+0x01)
	#define	CT1HZ_SFT							7
	#define	CT2HZ_SFT							6
	#define	CT4HZ_SFT							5
	#define	CT8HZ_SFT							4
	#define	CT16HZ_SFT							3
	#define	CT32HZ_SFT							2
	#define	CT64HZ_SFT							1
	#define	CT128HZ_SFT							0
	#define	CT1HZ								BIT(0x01, CT1HZ_SFT)		// 1HZ
	#define	CT2HZ								BIT(0x01, CT2HZ_SFT)		// 2HZ
	#define	CT4HZ								BIT(0x01, CT4HZ_SFT)		// 4HZ
	#define	CT8HZ								BIT(0x01, CT8HZ_SFT)		// 8HZ
	#define	CT16HZ								BIT(0x01, CT16HZ_SFT)		// 16HZ
	#define	CT32HZ								BIT(0x01, CT32HZ_SFT)		// 32HZ
	#define	CT64HZ								BIT(0x01, CT64HZ_SFT)		// 64HZ
	#define	CT128HZ								BIT(0x01, CT128HZ_SFT)		// 128HZ

#ifdef	BIT_FIELD
#define CT_CNT								*(volatile unsigned char *)(BASE_ADDR+0x1001)
	#define CT_CNT_CTCNT							CT_CNT					// Clock timer counter value
#endif	// end of BIT_FIELD

// Clock Timer Interrupt Mask Register
#define	R08_CT_IMSK							(volatile unsigned char *)(unsigned long)(CT_BASE_ADDR+0x02)
	#define	CTIE32_SFT							3
	#define	CTIE8_SFT							2
	#define	CTIE2_SFT							1
	#define	CTIE1_SFT							0
	#define	CTIE32								BIT(0x01, CTIE32_SFT)		// 32 Hz Interrupt Enable
	#define	CTIE8								BIT(0x01, CTIE8_SFT)		// 8 Hz Interrupt Enable
	#define	CTIE2								BIT(0x01, CTIE2_SFT)		// 2 Hz Interrupt Enable
	#define	CTIE1								BIT(0x01, CTIE1_SFT)		// 1 Hz Interrupt Enable
		#define	CT_DISABLE							0x00						// disable
		#define	CT_ENABLE							0x01						// enable
		#define	CT_INT_MASK							(CTIE32 | CTIE8 | CTIE2 | CTIE1)
																				// interrupt mask data

#ifdef	BIT_FIELD
#define CT_IMSK								*(volatile unsigned char *)(BASE_ADDR+0x1002)
#define BF_CT_IMSK							(*(volatile struct swt_imskBitF *)(BASE_ADDR+0x1002))
	#define CT_IMSK_CTIE32						BF_CT_IMSK.ctie32			// 32 Hz interrupt enable
	#define CT_IMSK_CTIE8						BF_CT_IMSK.ctie8			// 8 Hz interrupt enable
	#define CT_IMSK_CTIE2						BF_CT_IMSK.ctie2			// 2 Hz interrupt enable
	#define CT_IMSK_CTIE1						BF_CT_IMSK.ctie1			// 1 Hz interrupt enable
#endif	// end of BIT_FIELD


// Clock Timer Interrupt Flag Register
#define	R08_CT_IFLG							(volatile unsigned char *)(unsigned long)(CT_BASE_ADDR+0x03)
	#define	CTIF32_SFT							3
	#define	CTIF8_SFT							2
	#define	CTIF2_SFT							1
	#define	CTIF1_SFT							0
	#define	CTIF32								BIT(0x01, CTIF32_SFT)		// 32 Hz Interrupt Flag
	#define	CTIF8								BIT(0x01, CTIF8_SFT)		// 8 Hz Interrupt Flag
	#define	CTIF2								BIT(0x01, CTIF2_SFT)		// 2 Hz Interrupt Flag
	#define	CTIF1								BIT(0x01, CTIF1_SFT)		// 1 Hz Interrupt Flag
		#define	CT_NOTOCCURRED						0x00						// not occurred
		#define	CT_OCCURRED							0x01						// occurred

#ifdef	BIT_FIELD
#define CT_IFLG								*(volatile unsigned char *)(BASE_ADDR+0x1003)
#define BF_CT_IFLG							(*(volatile struct swt_iflgBitF *)(BASE_ADDR+0x1003))
	#define CT_IFLG_CTIF32						BF_CT_IFLG.ctif32			// 32 Hz interrupt flag  (read only)
	#define CT_IFLG_CTIF8						BF_CT_IFLG.ctif8			// 8 Hz interrupt flag  (read only)
	#define CT_IFLG_CTIF2						BF_CT_IFLG.ctif2			// 2 Hz interrupt flag  (read only)
	#define CT_IFLG_CTIF1						BF_CT_IFLG.ctif1			// 1 Hz interrupt flag  (read only)
#endif	// end of BIT_FIELD


#endif	// end of CT_H_
