/******************************************************************
 * misc.h
 * 
 * MISC driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef MISC_H_
#define MISC_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct misc_flBitF {
	unsigned int	flcyc		: 3;
	unsigned int				: 13;
};

struct misc_osc1BitF {
	unsigned int	o1dbg		: 1;
	unsigned int				: 15;
};

struct misc_iramszBitF {
	unsigned int	iramsz		: 3;
#ifdef	S1C17602
	unsigned int				: 5;
#else
	unsigned int				: 1;
	unsigned int	iramactsz	: 3;
	unsigned int				: 1;
#endif	// end of S1C17602
	unsigned int	dbadr		: 1;
	unsigned int				: 7;
};

struct misc_ttbrlBitF {
	unsigned int	ttbrl0_7	: 8;
	unsigned int	ttbrl8_15	: 8;
};

struct misc_ttblhBitF {
	unsigned int	ttbrh		: 8;
	unsigned int				: 8;
};

struct misc_psrBitF {
	unsigned int	psrn		: 1;
	unsigned int	psrz		: 1;
	unsigned int	psrv		: 1;
	unsigned int	psrc		: 1;
	unsigned int	psrie		: 1;
	unsigned int	psril		: 3;
	unsigned int				: 8;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	MISC_BASE_ADDR						(BASE_ADDR+MISC_OFFSET)


/***********************************************
 ****** The Definition of MISC Registers *******
 ****** [MISC]                           *******
 ***********************************************/
// FLASHC/SRAMC Control Register
#define	R16_MISC_FL							(volatile unsigned short *)(unsigned long)(MISC_BASE_ADDR+0x00)
	#define	FLCYC_SFT							0
	#define	FLCYC								BIT(0x0007, FLCYC_SFT)		// FLASHC read access cycle

#ifdef	BIT_FIELD
#define MISC_FL								*(volatile unsigned short *)(BASE_ADDR+0x1320)
#define BF_MISC_FL							(*(volatile struct misc_flBitF *)(BASE_ADDR+0x1320))
	#define MISC_FL_FLCYC						BF_MISC_FL.flcyc			// FLASHC read access cycle
#endif	// end of BIT_FIELD


// OSC1 Peripheral Control Register
#define	R16_MISC_OSC1						(volatile unsigned short *)(unsigned long)(MISC_BASE_ADDR+0x02)
	#define	O1DBG_SFT							0
	#define	O1DBG								BIT(0x0001, O1DBG_SFT)		// OSC1 peripheral control in debug mode
		#define	MISC_STOP							0x0000						// stop
		#define	MISC_RUN							0x0001						// run

#ifdef	BIT_FIELD
#define MISC_OSC1							*(volatile unsigned short *)(BASE_ADDR+0x1322)
#define BF_MISC_OSC1						(*(volatile struct misc_osc1BitF *)(BASE_ADDR+0x1322))
	#define MISC_OSC1_O1DBG						BF_MISC_OSC1.o1dbg			// OSC1 peripheral control in debug mode
#endif	// end of BIT_FIELD


// MISC ProtectRegister
#define	R16_MISC_PROT						(volatile unsigned short *)(unsigned long)(MISC_BASE_ADDR+0x04)
		#define	PROTECT_ON							0x0000						// protect on
		#define	PROTECT_OFF							0x0096						// protect off

#ifdef	BIT_FIELD
#define MISC_PROT							*(volatile unsigned short *)(BASE_ADDR+0x1324)
	#define MISC_PROT_PROT						MISC_PROT					// MISC Register write protect
#endif	// end of BIT_FIELD


// IRAM Size Select Register
#define	R16_MISC_IRAMSZ						(volatile unsigned short *)(unsigned long)(MISC_BASE_ADDR+0x06)
	#define	DBADR_SFT							8
	#define	IRAMACTSZ_SFT						4
	#define	IRAMSZ_SFT							0
	#define	DBADR								BIT(0x0001, DBADR_SFT)		// Debug base address select
		#define	MISC_ADDRESS_F						0x0000						// select debug base address 0xfffc00
		#define	MISC_ADDRESS_0						0x0001						//							 0x000000
	#define	IRAMACTSZ							BIT(0x0007, IRAMACTSZ_SFT)	// IRAM actual size register
	#define	IRAMSZ								BIT(0x0007, IRAMSZ_SFT)		// IRAM size select

#ifdef	BIT_FIELD
#define MISC_IRAMSZ							*(volatile unsigned short *)(BASE_ADDR+0x1326)
#define BF_MISC_IRAMSZ						(*(volatile struct misc_iramszBitF *)(BASE_ADDR+0x1326))
	#define MISC_IRAMSZ_DBADR					BF_MISC_IRAMSZ.dbadr		// Debug base address select
	#define MISC_IRAMSZ_IRAMACTSZ				BF_MISC_IRAMSZ.iramactsz	// IRAM actual size register
	#define MISC_IRAMSZ_IRAMSZ					BF_MISC_IRAMSZ.iramsz		// IRAM size select
#endif	// end of BIT_FIELD


// Vector Table Address Low Register
#define	R16_MISC_TTBRL						(volatile unsigned short *)(unsigned long)(MISC_BASE_ADDR+0x08)
	#define	TTBRL_SFT							8
	#define	TTBRL								BIT(0x00ff, TTBRL_SFT)		// Vector table base address A[15:8]
		#define	MISC_DATA_MAX						0x00ff						// data max

#ifdef	BIT_FIELD
#define MISC_TTBRL							*(volatile unsigned short *)(BASE_ADDR+0x1328)
#define BF_MISC_TTBRL						(*(volatile struct misc_ttbrlBitF *)(BASE_ADDR+0x1328))
	#define MISC_TTBRL_8_15						BF_MISC_TTBRL.ttbrl8_15		// Vector table base address [15:8]
	#define MISC_TTBRL_0_7						BF_MISC_TTBRL.ttbrl0_7		// Vector table base address [7:0]
#endif	// end of BIT_FIELD


// Vector Table Address High Register
#define	R16_MISC_TTBRH						(volatile unsigned short *)(unsigned long)(MISC_BASE_ADDR+0x0a)
	#define	TTBRH_SFT							0
	#define	TTBRH								BIT(0x00ff, TTBRH_SFT)		// Vector table base address A[23:16]

#ifdef	BIT_FIELD
#define MISC_TTBRH							*(volatile unsigned short *)(BASE_ADDR+0x132a)
#define BF_MISC_TTBRH						(*(volatile struct misc_ttblhBitF *)(BASE_ADDR+0x132a))
	#define MISC_TTBRH_16_23					BF_MISC_TTBRH.ttbrh			// Vector table base address [23:16]
#endif	// end of BIT_FIELD


// PSR Register
#define	R16_MISC_PSR						(volatile unsigned short *)(unsigned long)(MISC_BASE_ADDR+0x0c)
	#define	PSRIL_SFT							5
	#define	PSRIE_SFT							4
	#define	PSRC_SFT							3
	#define	PSRV_SFT							2
	#define	PSRZ_SFT							1
	#define	PSRN_SFT							0
	#define	PSRIL								BIT(0x0007, PSRIL_SFT)		// PSR interrupt level (IL) bits
	#define	PSRIE								BIT(0x0001, PSRIE_SFT)		// PSR interrupt enable (IE) bit
	#define	PSRC								BIT(0x0001, PSRC_SFT)		// PSR carry (C) flag
	#define	PSRV								BIT(0x0001, PSRV_SFT)		// PSR overflow (V) flag
	#define	PSRZ								BIT(0x0001, PSRZ_SFT)		// PSR zero (Z) flag
	#define	PSRN								BIT(0x0001, PSRN_SFT)		// PSR negative (N) flag

#ifdef	BIT_FIELD
#define MISC_PSR							*(volatile unsigned short *)(BASE_ADDR+0x132c)
#define BF_MISC_PSR							(*(volatile struct misc_psrBitF *)(BASE_ADDR+0x132c))
	#define MISC_PSR_PSRIL						BF_MISC_PSR.psril			// PSR Interrupt level (IL) bits
	#define MISC_PSR_PSRIE						BF_MISC_PSR.psrie			// PSR Interrupt enable (IE) bits
	#define MISC_PSR_PSRC						BF_MISC_PSR.psrc			// PSR carry (C) flag
	#define MISC_PSR_PSRV						BF_MISC_PSR.psrv			// PSR overflow (V) flag
	#define MISC_PSR_PSRZ						BF_MISC_PSR.psrz			// PSR zero (Z) flag
	#define MISC_PSR_PSRN						BF_MISC_PSR.psrn			// PSR negative (N) flag
#endif	// end of BIT_FIELD


#endif	// end of MISC_H_
