/******************************************************************
 * mux.h
 * 
 * MUX driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef MUX_H_
#define MUX_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct mux_p03muxBitF {
	unsigned int	px0mux	: 2;
	unsigned int	px1mux	: 2;
	unsigned int	px2mux	: 2;
	unsigned int	px3mux	: 2;
};

struct mux_p47muxBitF {
	unsigned int	px4mux	: 2;
	unsigned int	px5mux	: 2;
	unsigned int	px6mux	: 2;
	unsigned int	px7mux	: 2;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	MUX_BASE_ADDR						(BASE_ADDR+MUX_OFFSET)


/***********************************************
 ****** The Definition of Port MUX          ****
 ****** [Px]                                ****
 ***********************************************/
// P0 Port Function Select Register
#define	R08_P0L_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x00)
	#define	PX3MUX_SFT							6
	#define	PX2MUX_SFT							4
	#define	PX1MUX_SFT							2
	#define	PX0MUX_SFT							0
	#define	P03MUX								BIT(0x03, PX3MUX_SFT)		// P03 port function select
		#define	P03									BIT(0x00, PX3MUX_SFT)		// P03
#ifndef	S1C17611
		#define	xADTRG								BIT(0x01, PX3MUX_SFT)		// #ADTRG
#else
		#define	AIN3								BIT(0x01, PX3MUX_SFT)		// AIN3
		#define	SCL0								BIT(0x02, PX3MUX_SFT)		// SCL0
		#define	SCL1								BIT(0x03, PX3MUX_SFT)		// SCL1
#endif	// end of S1C17611
	#define	P02MUX								BIT(0x03, PX2MUX_SFT)		// P02 port function select
#ifndef	S1C17611
		#define	P02									BIT(0x00, PX2MUX_SFT)		// P02/EXCL0(T16 Ch.0)
#else
		#define	P02									BIT(0x00, PX2MUX_SFT)		// P02
#endif	// end of S1C17611
#ifndef	S1C17602
		#define	TOUT4								BIT(0x01, PX2MUX_SFT)		// TOUT4
#endif	// end of S1C17602
#ifdef	S1C17611
		#define	RFCLKO								BIT(0x02, PX2MUX_SFT)		// RFCLKO
#endif	// end of S1C17611
	#define	P01MUX								BIT(0x03, PX1MUX_SFT)		// P01 port function select
		#define	P01									BIT(0x00, PX1MUX_SFT)		// P01
#ifdef	S1C17602
		#define	REMI								BIT(0x01, PX1MUX_SFT)		// REMI
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	TOUTN4								BIT(0x01, PX1MUX_SFT)		// TOUTN4
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	OSC3								BIT(0x01, PX1MUX_SFT)		// OSC3
		#define	XOSC3								BIT(0x02, PX1MUX_SFT)		// XOSC3
#endif	// end of S1C17611
	#define	P00MUX								BIT(0x03, PX0MUX_SFT)		// P00 port function select
		#define	P00									BIT(0x00, PX0MUX_SFT)		// P00
#ifdef	S1C17602
		#define	REMO								BIT(0x01, PX0MUX_SFT)		// REMO
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	RFCLKO								BIT(0x01, PX0MUX_SFT)		// RFCLKO
		#define	LFRO								BIT(0x02, PX0MUX_SFT)		// LFRO
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	OSC4								BIT(0x01, PX0MUX_SFT)		// OSC4
		#define	FOUT1_0								BIT(0x02, PX0MUX_SFT)		// FOUT1
#endif	// end of S1C17611

#ifdef	BIT_FIELD
#define P0_PMUX0_3							*(volatile unsigned char *)(BASE_ADDR+0x12a0)
#define BF_P0_PMUX0_3						(*(volatile struct mux_p03muxBitF *)(BASE_ADDR+0x12a0))
	#define P0_PMUX0_3_P03MUX					BF_P0_PMUX0_3.px3mux		// P03 port function select
	#define P0_PMUX0_3_P02MUX					BF_P0_PMUX0_3.px2mux		// P02 port function select
	#define P0_PMUX0_3_P01MUX					BF_P0_PMUX0_3.px1mux		// P01 port function select
	#define P0_PMUX0_3_P00MUX					BF_P0_PMUX0_3.px0mux		// P00 port function select
#endif	// end of BIT_FIELD


// P0 Port Function Select Register
#define	R08_P0H_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x01)
	#define	PX7MUX_SFT							6
	#define	PX6MUX_SFT							4
	#define	PX5MUX_SFT							2
	#define	PX4MUX_SFT							0
	#define	P07MUX								BIT(0x03, PX7MUX_SFT)		// P07 port function select
#ifdef	S1C17602
		#define	P07									BIT(0x00, PX7MUX_SFT)		// P07
		#define	xSPISS								BIT(0x01, PX7MUX_SFT)		// #SPISS
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	P07									BIT(0x00, PX7MUX_SFT)		// P07/EXCL4(T16E Ch.1)
		#define	AIN0								BIT(0x01, PX7MUX_SFT)		// AIN0
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	P07									BIT(0x00, PX7MUX_SFT)		// P07
		#define	RFIN0								BIT(0x01, PX7MUX_SFT)		// RFIN
		#define	FOUTH								BIT(0x02, PX7MUX_SFT)		// FOUTH
#endif	// end of S1C17611
	#define	P06MUX								BIT(0x03, PX6MUX_SFT)		// P06 port function select
#ifdef	S1C17602
		#define	P06									BIT(0x00, PX6MUX_SFT)		// P06
		#define	SDI									BIT(0x01, PX6MUX_SFT)		// SDI
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	P06									BIT(0x00, PX6MUX_SFT)		// P06/EXCL3(T16E Ch.0)
		#define	AIN1								BIT(0x01, PX6MUX_SFT)		// AIN1
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	P06									BIT(0x00, PX6MUX_SFT)		// P06
		#define	AIN0								BIT(0x01, PX6MUX_SFT)		// AIN0
		#define	FOUT1								BIT(0x02, PX6MUX_SFT)		// FOUT1
		#define	LFRO								BIT(0x03, PX6MUX_SFT)		// LFRO
#endif	// end of S1C17611
	#define	P05MUX								BIT(0x03, PX5MUX_SFT)		// P05 port function select
#ifdef	S1C17602
		#define	P05									BIT(0x00, PX5MUX_SFT)		// P05
		#define	SDO									BIT(0x01, PX5MUX_SFT)		// SDO
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	P05									BIT(0x00, PX5MUX_SFT)		// P05/EXCL2(T16 Ch.2)
		#define	AIN2								BIT(0x01, PX5MUX_SFT)		// AIN2
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	P05									BIT(0x00, PX5MUX_SFT)		// P05(EXCL3)
		#define	AIN1								BIT(0x01, PX5MUX_SFT)		// AIN1
		#define	T8OUT								BIT(0x02, PX5MUX_SFT)		// TOUT5
#endif	// end of S1C17611
	#define	P04MUX								BIT(0x03, PX4MUX_SFT)		// P04 port function select
#ifdef	S1C17602
		#define	P04									BIT(0x00, PX4MUX_SFT)		// P04
		#define	SPICLK								BIT(0x01, PX4MUX_SFT)		// SPICLK
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	P04									BIT(0x00, PX4MUX_SFT)		// P04/EXCL1(T16 Ch.1)
		#define	AIN3								BIT(0x01, PX4MUX_SFT)		// AIN3
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	P04									BIT(0x00, PX4MUX_SFT)		// P04
		#define	AIN2								BIT(0x01, PX4MUX_SFT)		// AIN2
		#define	SDA0								BIT(0x02, PX4MUX_SFT)		// SDA0
		#define	SDA1								BIT(0x03, PX4MUX_SFT)		// SDA1
#endif	// end of S1C17611

#ifdef	BIT_FIELD
#define P0_PMUX4_7							*(volatile unsigned char *)(BASE_ADDR+0x12a1)
#define BF_P0_PMUX4_7						(*(volatile struct mux_p47muxBitF *)(BASE_ADDR+0x12a1))
	#define P0_PMUX4_7_P07MUX					BF_P0_PMUX4_7.px7mux		// P07 port function select
	#define P0_PMUX4_7_P06MUX					BF_P0_PMUX4_7.px6mux		// P06 port function select
	#define P0_PMUX4_7_P05MUX					BF_P0_PMUX4_7.px5mux		// P05 port function select
	#define P0_PMUX4_7_P04MUX					BF_P0_PMUX4_7.px4mux		// P04 port function select
#endif	// end of BIT_FIELD


// P1 Port Function Select Register
#define	R08_P1L_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x02)
	#define	P13MUX								BIT(0x03, PX3MUX_SFT)		// P13 port function select
		#define	P13									BIT(0x00, PX3MUX_SFT)		// P13/EXCL1(T16 Ch.1)
#ifdef	S1C17602
		#define	AIN7								BIT(0x02, PX3MUX_SFT)		// AIN7
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	SENA0								BIT(0x01, PX3MUX_SFT)		// SENA
		#define	SDA1_1								BIT(0x02, PX3MUX_SFT)		// SDA1
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	SOUT								BIT(0x01, PX3MUX_SFT)		// SOUT
		#define	FOUTH_0								BIT(0x02, PX3MUX_SFT)		// FOUTH
		#define	TOUTN3								BIT(0x03, PX3MUX_SFT)		// TOUTN3
#endif	// end of S1C17611
	#define	P12MUX								BIT(0x03, PX2MUX_SFT)		// P12 port function select
		#define	P12									BIT(0x00, PX2MUX_SFT)		// P12
#ifdef	S1C17602
		#define	SIN									BIT(0x01, PX2MUX_SFT)		// SIN
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	SENB0								BIT(0x01, PX2MUX_SFT)		// SENB
		#define	xBFR								BIT(0x02, PX2MUX_SFT)		// #BFR
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	SENB0								BIT(0x01, PX2MUX_SFT)		// SENB
		#define	SCLK								BIT(0x02, PX2MUX_SFT)		// SCLK
		#define	TOUT3								BIT(0x03, PX2MUX_SFT)		// TOUT3
#endif	// end of S1C17611
	#define	P11MUX								BIT(0x03, PX1MUX_SFT)		// P11 port function select
		#define	P11									BIT(0x00, PX1MUX_SFT)		// P11
#ifdef	S1C17602
		#define	SOUT								BIT(0x01, PX1MUX_SFT)		// SOUT
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	SDA0_0								BIT(0x01, PX1MUX_SFT)		// SDA0
		#define	SDA1_0								BIT(0x02, PX1MUX_SFT)		// SDA1
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	SENA0								BIT(0x01, PX1MUX_SFT)		// SENA
		#define	TOUT5								BIT(0x02, PX1MUX_SFT)		// TOUT5
#endif	// end of S1C17611
	#define	P10MUX								BIT(0x03, PX0MUX_SFT)		// P10 port function select
		#define	P10									BIT(0x00, PX0MUX_SFT)		// P10
#ifdef	S1C17602
		#define	SCLK								BIT(0x01, PX0MUX_SFT)		// SCLK
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	SCL0_0								BIT(0x01, PX0MUX_SFT)		// SCL0
		#define	SCL1_0								BIT(0x02, PX0MUX_SFT)		// SCL1
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	REF0								BIT(0x01, PX0MUX_SFT)		// REF
		#define	TOUTN4								BIT(0x02, PX0MUX_SFT)		// TOUTN4
#endif	// end of S1C17611

#ifdef	BIT_FIELD
#define P1_PMUX0_3							*(volatile unsigned char *)(BASE_ADDR+0x12a2)
#define BF_P1_PMUX0_3						(*(volatile struct mux_p03muxBitF *)(BASE_ADDR+0x12a2))
	#define P1_PMUX0_3_P13MUX					BF_P1_PMUX0_3.px3mux		// P13 port function select
	#define P1_PMUX0_3_P12MUX					BF_P1_PMUX0_3.px2mux		// P12 port function select
	#define P1_PMUX0_3_P11MUX					BF_P1_PMUX0_3.px1mux		// P11 port function select
	#define P1_PMUX0_3_P10MUX					BF_P1_PMUX0_3.px0mux		// P10 port function select
#endif	// end of BIT_FIELD


// P1 Port Function Select Register
#define	R08_P1H_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x03)
	#define	P17MUX								BIT(0x03, PX7MUX_SFT)		// P17 port function select
#ifdef	S1C17602
		#define	P17									BIT(0x00, PX7MUX_SFT)		// P17
		#define	AIN3								BIT(0x01, PX7MUX_SFT)		// AIN3
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	P17									BIT(0x00, PX7MUX_SFT)		// P17
		#define	SPICLK								BIT(0x01, PX7MUX_SFT)		// SPICLK
		#define	SCLK								BIT(0x02, PX7MUX_SFT)		// SCLK
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	P17									BIT(0x00, PX7MUX_SFT)		// P17(EXCL1)
		#define	SDO									BIT(0x01, PX7MUX_SFT)		// SDO
#endif	// end of S1C17611
	#define	P16MUX								BIT(0x03, PX6MUX_SFT)		// P16 port function select
#ifdef	S1C17602
		#define	P16									BIT(0x00, PX6MUX_SFT)		// P16
		#define	SCLK1								BIT(0x01, PX6MUX_SFT)		// SCLK1
		#define	AIN4								BIT(0x02, PX6MUX_SFT)		// AIN4
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	P16									BIT(0x00, PX6MUX_SFT)		// P16
		#define	FOUT1								BIT(0x01, PX6MUX_SFT)		// FOUT1
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	P16									BIT(0x00, PX6MUX_SFT)		// P16(EXCL2)
		#define	SDI									BIT(0x01, PX6MUX_SFT)		// SDI
#endif	// end of S1C17611
	#define	P15MUX								BIT(0x03, PX5MUX_SFT)		// P15 port function select
#ifdef	S1C17602
		#define	P15									BIT(0x00, PX5MUX_SFT)		// P15/EXCL3(T16E Ch.0)
		#define	AIN5								BIT(0x02, PX5MUX_SFT)		// AIN5
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	P15									BIT(0x00, PX5MUX_SFT)		// P15
		#define	RFIN0								BIT(0x01, PX5MUX_SFT)		// RFIN
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	P15									BIT(0x00, PX5MUX_SFT)		// P15
		#define	xSPISS								BIT(0x01, PX5MUX_SFT)		// #SPISS
		#define	xBFR								BIT(0x02, PX5MUX_SFT)		// #BFR
		#define	TOUT3_0								BIT(0x03, PX5MUX_SFT)		// TOUT3
#endif	// end of S1C17611
	#define	P14MUX								BIT(0x03, PX4MUX_SFT)		// P14 port function select
#ifdef	S1C17602
		#define	P14									BIT(0x00, PX4MUX_SFT)		// P14/EXCL2(T16 Ch.2)
		#define	AIN6								BIT(0x02, PX4MUX_SFT)		// AIN6
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	P14									BIT(0x00, PX4MUX_SFT)		// P14
		#define	REF0								BIT(0x01, PX4MUX_SFT)		// REF
		#define	SCL1_1								BIT(0x02, PX4MUX_SFT)		// SCL1
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	P14									BIT(0x00, PX4MUX_SFT)		// P14(EXCL5)
		#define	SIN									BIT(0x01, PX4MUX_SFT)		// SIN
		#define	xADTRG								BIT(0x02, PX4MUX_SFT)		// #ADTRG
#endif	// end of S1C17611

#ifdef	BIT_FIELD
#define P1_PMUX4_7							*(volatile unsigned char *)(BASE_ADDR+0x12a3)
#define BF_P1_PMUX4_7						(*(volatile struct mux_p47muxBitF *)(BASE_ADDR+0x12a3))
	#define P1_PMUX4_7_P17MUX					BF_P1_PMUX4_7.px7mux		// P17 port function select
	#define P1_PMUX4_7_P16MUX					BF_P1_PMUX4_7.px6mux		// P16 port function select
	#define P1_PMUX4_7_P15MUX					BF_P1_PMUX4_7.px5mux		// P15 port function select
	#define P1_PMUX4_7_P14MUX					BF_P1_PMUX4_7.px4mux		// P14 port function select
#endif	// end of BIT_FIELD


// P2 Port Function Select Register
#define	R08_P2L_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x04)
#ifndef	S1C17611
	#define	P23MUX								BIT(0x03, PX3MUX_SFT)		// P23 port function select
		#define	P23									BIT(0x00, PX3MUX_SFT)		// P23
#ifdef	S1C17602
		#define	SENB0								BIT(0x01, PX3MUX_SFT)		// SENB0
#else
		#define	TOUT3								BIT(0x01, PX3MUX_SFT)		// TOUT3
		#define	SOUT1								BIT(0x02, PX3MUX_SFT)		// SOUT
#endif	// end of S1C17602
#endif	// end of S1C17611
	#define	P22MUX								BIT(0x03, PX2MUX_SFT)		// P22 port function select
#ifdef	S1C17602
		#define	P22									BIT(0x00, PX2MUX_SFT)		// P22
		#define	AIN0								BIT(0x01, PX2MUX_SFT)		// AIN0
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	P22									BIT(0x00, PX2MUX_SFT)		// P22
		#define	xSPISS								BIT(0x01, PX2MUX_SFT)		// #SPISS
		#define	FOUTH								BIT(0x02, PX2MUX_SFT)		// FOUTH
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	DST2								BIT(0x00, PX2MUX_SFT)		// DST2
		#define	P22									BIT(0x01, PX2MUX_SFT)		// P22
#endif	// end of S1C17611
	#define	P21MUX								BIT(0x03, PX1MUX_SFT)		// P21 port function select
#ifdef	S1C17602
		#define	P21									BIT(0x00, PX1MUX_SFT)		// P21
		#define	AIN1								BIT(0x01, PX1MUX_SFT)		// AIN1
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	P21									BIT(0x00, PX1MUX_SFT)		// P21
		#define	SDI									BIT(0x01, PX1MUX_SFT)		// SDI
		#define	SIN									BIT(0x02, PX1MUX_SFT)		// SIN
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	DSIO								BIT(0x00, PX1MUX_SFT)		// DSIO
		#define	P21									BIT(0x01, PX1MUX_SFT)		// P21
#endif	// end of S1C17611
	#define	P20MUX								BIT(0x03, PX0MUX_SFT)		// P20 port function select
#ifdef	S1C17602
		#define	P20									BIT(0x00, PX0MUX_SFT)		// P20
		#define	AIN2								BIT(0x01, PX0MUX_SFT)		// AIN2
#endif	// end of S1C17602
#ifdef	S1C17601
		#define	P20									BIT(0x00, PX0MUX_SFT)		// P20
		#define	SDO									BIT(0x01, PX0MUX_SFT)		// SDO
		#define	SOUT								BIT(0x02, PX0MUX_SFT)		// SOUT
#endif	// end of S1C17601
#ifdef	S1C17611
		#define	P20									BIT(0x00, PX0MUX_SFT)		// P20(EXCL0)
		#define	SPICLK								BIT(0x01, PX0MUX_SFT)		// SPICLK
		#define	TOUT4_0								BIT(0x02, PX0MUX_SFT)		// TOUT4
#endif	// end of S1C17611

#ifdef	BIT_FIELD
#define P2_PMUX0_3							*(volatile unsigned char *)(BASE_ADDR+0x12a4)
#define BF_P2_PMUX0_3						(*(volatile struct mux_p03muxBitF *)(BASE_ADDR+0x12a4))
	#define P2_PMUX0_3_P23MUX					BF_P2_PMUX0_3.px3mux		// P23 port function select
	#define P2_PMUX0_3_P22MUX					BF_P2_PMUX0_3.px2mux		// P22 port function select
	#define P2_PMUX0_3_P21MUX					BF_P2_PMUX0_3.px1mux		// P21 port function select
	#define P2_PMUX0_3_P20MUX					BF_P2_PMUX0_3.px0mux		// P20 port function select
#endif	// end of BIT_FIELD


#ifndef	S1C17611

// P2 Port Function Select Register
#define	R08_P2H_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x05)
	#define	P27MUX								BIT(0x03, PX7MUX_SFT)		// P27 port function select
#ifdef	S1C17602
		#define	P27									BIT(0x00, PX7MUX_SFT)		// P27
		#define	SOUT1								BIT(0x01, PX7MUX_SFT)		// SOUT1
		#define	RFIN1								BIT(0x02, PX7MUX_SFT)		// RFIN1
#else
		#define	DCLK								BIT(0x00, PX7MUX_SFT)		// DCLK
		#define	P27									BIT(0x01, PX7MUX_SFT)		// P27
#endif	// end of S1C17602
	#define	P26MUX								BIT(0x01, PX6MUX_SFT)		// P26 port function select
#ifdef	S1C17602
		#define	P26									BIT(0x00, PX6MUX_SFT)		// P26
		#define	RFIN0								BIT(0x01, PX6MUX_SFT)		// RFIN0
#else
		#define	DST2								BIT(0x00, PX6MUX_SFT)		// DST2
		#define	P26									BIT(0x01, PX6MUX_SFT)		// P26
#endif	// end of S1C17602
	#define	P25MUX								BIT(0x01, PX5MUX_SFT)		// P25 port function select
#ifdef	S1C17602
		#define	P25									BIT(0x00, PX5MUX_SFT)		// P25
		#define	REF0								BIT(0x01, PX5MUX_SFT)		// REF0
#else
		#define	DSIO								BIT(0x00, PX5MUX_SFT)		// DSIO
		#define	P25									BIT(0x01, PX5MUX_SFT)		// P25
#endif	// end of S1C17602
	#define	P24MUX								BIT(0x03, PX4MUX_SFT)		// P24 port function select
		#define	P24									BIT(0x00, PX4MUX_SFT)		// P24
#ifdef	S1C17602
		#define	SENA0								BIT(0x01, PX4MUX_SFT)		// SENA0
#else
		#define	TOUTN3								BIT(0x01, PX4MUX_SFT)		// TOUTN3
		#define	SIN1								BIT(0x02, PX4MUX_SFT)		// SIN
		#define	T8OUT								BIT(0x03, PX4MUX_SFT)		// T8OUT
#endif	// end of S1C17602

#ifdef	BIT_FIELD
#define P2_PMUX4_7							*(volatile unsigned char *)(BASE_ADDR+0x12a5)
#define BF_P2_PMUX4_7						(*(volatile struct mux_p47muxBitF *)(BASE_ADDR+0x12a5))
	#define P2_PMUX4_7_P27MUX					BF_P2_PMUX4_7.px7mux		// P27 port function select
	#define P2_PMUX4_7_P26MUX					BF_P2_PMUX4_7.px6mux		// P26 port function select
	#define P2_PMUX4_7_P25MUX					BF_P2_PMUX4_7.px5mux		// P25 port function select
	#define P2_PMUX4_7_P24MUX					BF_P2_PMUX4_7.px4mux		// P24 port function select
#endif	// end of BIT_FIELD


#ifdef	S1C17602


// P3 Port Function Select Register
#define	R08_P3L_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x06)
	#define	P33MUX								BIT(0x03, PX3MUX_SFT)		// P33 port function select
		#define	P33									BIT(0x00, PX3MUX_SFT)		// P33
		#define	SCL1								BIT(0x01, PX3MUX_SFT)		// SCL1
		#define	SCL0_1								BIT(0x02, PX3MUX_SFT)		// SCL0_1
	#define	P32MUX								BIT(0x03, PX2MUX_SFT)		// P32 port function select
		#define	P32									BIT(0x00, PX2MUX_SFT)		// P32
		#define	SDA0_0								BIT(0x01, PX2MUX_SFT)		// SDA0_0
		#define	SENB1								BIT(0x02, PX2MUX_SFT)		// SENB1
	#define	P31MUX								BIT(0x03, PX1MUX_SFT)		// P31 port function select
		#define	P31									BIT(0x00, PX1MUX_SFT)		// P31
		#define	SCL0_0								BIT(0x01, PX1MUX_SFT)		// SCL0_0
		#define	SENA1								BIT(0x02, PX1MUX_SFT)		// SENA1
	#define	P30MUX								BIT(0x03, PX0MUX_SFT)		// P30 port function select
		#define	P30									BIT(0x00, PX0MUX_SFT)		// P30
		#define	SIN1								BIT(0x01, PX0MUX_SFT)		// SIN1(UART)
		#define	REF1								BIT(0x02, PX0MUX_SFT)		// REF1

#ifdef	BIT_FIELD
#define P3_PMUX0_3							*(volatile unsigned char *)(BASE_ADDR+0x12a6)
#define BF_P3_PMUX0_3						(*(volatile struct mux_p03muxBitF *)(BASE_ADDR+0x12a6))
	#define P3_PMUX0_3_P33MUX					BF_P3_PMUX0_3.px3mux		// P33 port function select
	#define P3_PMUX0_3_P32MUX					BF_P3_PMUX0_3.px2mux		// P32 port function select
	#define P3_PMUX0_3_P31MUX					BF_P3_PMUX0_3.px1mux		// P31 port function select
	#define P3_PMUX0_3_P30MUX					BF_P3_PMUX0_3.px0mux		// P30 port function select
#endif	// end of BIT_FIELD


// P3 Port Function Select Register
#define	R08_P3H_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x07)
	#define	P37MUX								BIT(0x03, PX7MUX_SFT)		// P37 port function select
		#define	P37									BIT(0x00, PX7MUX_SFT)		// P37
		#define	TOUTN3								BIT(0x01, PX7MUX_SFT)		// TOUTN3
		#define	LFRO								BIT(0x02, PX7MUX_SFT)		// LFRO
		#define	TOUT4								BIT(0x03, PX7MUX_SFT)		// TOUT4
	#define	P36MUX								BIT(0x03, PX6MUX_SFT)		// P36 port function select
		#define	P36									BIT(0x00, PX6MUX_SFT)		// P36
		#define	TOUT3								BIT(0x01, PX6MUX_SFT)		// TOUT3
		#define	RFCLKO								BIT(0x02, PX6MUX_SFT)		// RFCLKO
	#define	P35MUX								BIT(0x03, PX5MUX_SFT)		// P35 port function select
		#define	P35									BIT(0x00, PX5MUX_SFT)		// P35
		#define	FOUT1								BIT(0x01, PX5MUX_SFT)		// FOUT1
		#define	xBFR								BIT(0x02, PX5MUX_SFT)		// #BFR
	#define	P34MUX								BIT(0x03, PX4MUX_SFT)		// P34 port function select
		#define	P34									BIT(0x00, PX4MUX_SFT)		// P34
		#define	SDA1								BIT(0x01, PX4MUX_SFT)		// SDA1
		#define	SDA0_1								BIT(0x02, PX4MUX_SFT)		// SDA0_1

#ifdef	BIT_FIELD
#define P3_PMUX4_7							*(volatile unsigned char *)(BASE_ADDR+0x12a7)
#define BF_P3_PMUX4_7						(*(volatile struct mux_p47muxBitF *)(BASE_ADDR+0x12a7))
	#define P3_PMUX4_7_P37MUX					BF_P3_PMUX4_7.px7mux		// P37 port function select
	#define P3_PMUX4_7_P36MUX					BF_P3_PMUX4_7.px6mux		// P36 port function select
	#define P3_PMUX4_7_P35MUX					BF_P3_PMUX4_7.px5mux		// P35 port function select
	#define P3_PMUX4_7_P34MUX					BF_P3_PMUX4_7.px4mux		// P34 port function select
#endif	// end of BIT_FIELD


// P4 Port Function Select Register
#define	R08_P4L_PMUX						(volatile unsigned char *)(unsigned long)(MUX_BASE_ADDR+0x08)
	#define	P43MUX								BIT(0x01, PX3MUX_SFT)		// P43 port function select
		#define	DCLK								BIT(0x00, PX3MUX_SFT)		// DCLK
		#define	P43									BIT(0x01, PX3MUX_SFT)		// P43
	#define	P42MUX								BIT(0x01, PX2MUX_SFT)		// P42 port function select
		#define	DST2								BIT(0x00, PX2MUX_SFT)		// DST2
		#define	P42									BIT(0x01, PX2MUX_SFT)		// P42
	#define	P41MUX								BIT(0x01, PX1MUX_SFT)		// P41 port function select
		#define	DSIO								BIT(0x00, PX1MUX_SFT)		// DSIO
		#define	P41									BIT(0x01, PX1MUX_SFT)		// P41
	#define	P40MUX								BIT(0x01, PX0MUX_SFT)		// P40 port function select
		#define	P40									BIT(0x00, PX0MUX_SFT)		// P40
		#define	FOUTH								BIT(0x01, PX0MUX_SFT)		// FOUTH

#ifdef	BIT_FIELD
#define P4_PMUX0_3							*(volatile unsigned char *)(BASE_ADDR+0x12a8)
#define BF_P4_PMUX0_3						(*(volatile struct mux_p03muxBitF *)(BASE_ADDR+0x12a8))
	#define P4_PMUX0_3_P43MUX					BF_P4_PMUX0_3.px3mux		// P43 port function select
	#define P4_PMUX0_3_P42MUX					BF_P4_PMUX0_3.px2mux		// P42 port function select
	#define P4_PMUX0_3_P41MUX					BF_P4_PMUX0_3.px1mux		// P41 port function select
	#define P4_PMUX0_3_P40MUX					BF_P4_PMUX0_3.px0mux		// P40 port function select
#endif	// end of BIT_FIELD


#endif	// end of S1C17602
#endif	// end of S1C17611


#endif	// end of MUX_H_
