/******************************************************************
 * port.h
 * 
 * PORT driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef PORT_H_
#define PORT_H_

#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct port_pxxBitF {
	unsigned int	pxx	: 4;
	unsigned int		: 4;
};

struct port_chatBitF {
	unsigned int	pxcf1	: 3;
	unsigned int			: 1;
	unsigned int	pxcf2	: 3;
	unsigned int			: 1;
};

struct port_krstBitF {
	unsigned int	p0krst	: 2;
	unsigned int			: 6;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define PORT_BASE_ADDR						(BASE_ADDR+PORT_OFFSET)


/***********************************************
 ****** The Definition of P Port            ****
 ****** [Px]                                ****
 ***********************************************/
// Px Port Input Data Register
#define R08_PX_IN(pno)						(volatile unsigned char *)(unsigned long)(PORT_BASE_ADDR+0x00+(pno*PORT_NO_OFFSET))
	#define BIT_PX7								BIT(0x01, 7)
	#define BIT_PX6								BIT(0x01, 6)
	#define BIT_PX5								BIT(0x01, 5)
	#define BIT_PX4								BIT(0x01, 4)
	#define BIT_PX3								BIT(0x01, 3)
	#define BIT_PX2								BIT(0x01, 2)
	#define BIT_PX1								BIT(0x01, 1)
	#define BIT_PX0								BIT(0x01, 0)

#ifdef	BIT_FIELD
#define P0_IN								*(volatile unsigned char *)(BASE_ADDR+0x1200)
	#define P0_IN_P0IN							P0_IN						// P0[7:0] port input data

#define P1_IN								*(volatile unsigned char *)(BASE_ADDR+0x1210)
	#define P1_IN_P1IN							P1_IN						// P1[7:0] port input data

#define P2_IN								*(volatile unsigned char *)(BASE_ADDR+0x1220)
	#define P2_IN_P2IN							P2_IN						// P2[7:0] port input data

#define P3_IN								*(volatile unsigned char *)(BASE_ADDR+0x1230)
	#define P3_IN_P3IN							P3_IN						// P3[7:0] port input data

#define P4_IN								*(volatile unsigned char *)(BASE_ADDR + 0x1240)
#define BF_P4_IN							(*(volatile struct port_pxxBitF *)(BASE_ADDR+0x1240))
	#define P4_IN_P4IN							BF_P4_IN.pxx				// P4[3:0] port input data
#endif	// end of BIT_FIELD


// Px Port Output Data Register
#define R08_PX_OUT(pno)						(volatile unsigned char *)(unsigned long)(PORT_BASE_ADDR+0x01+(pno*PORT_NO_OFFSET))

#ifdef	BIT_FIELD
#define P0_OUT								*(volatile unsigned char *)(BASE_ADDR+0x1201)
	#define P0_OUT_P0OUT						P0_OUT						// P0[7:0] port output data

#define P1_OUT								*(volatile unsigned char *)(BASE_ADDR+0x1211)
	#define P1_OUT_P1OUT						P1_OUT						// P1[7:0] port output data

#define P2_OUT								*(volatile unsigned char *)(BASE_ADDR+0x1221)
	#define P2_OUT_P2OUT						P2_OUT						// P2[7:0] port output data

#define P3_OUT								*(volatile unsigned char *)(BASE_ADDR+0x1231)
	#define P3_OUT_P3OUT						P3_OUT						// P3[7:0] port output data

#define P4_OUT								*(volatile unsigned char *)(BASE_ADDR+0x1241)
#define BF_P4_OUT							(*(volatile struct port_pxxBitF *)(BASE_ADDR+0x1241))
	#define P4_OUT_P4OUT						BF_P4_OUT.pxx				// P4[3:0] port output data
#endif	// end of BIT_FIELD


// Px Port Output Enable Register
#define R08_PX_OEN(pno)						(volatile unsigned char *)(unsigned long)(PORT_BASE_ADDR+0x02+(pno*PORT_NO_OFFSET))
	#define PORT_DISABLE						0x00						// disable
	#define PORT_ENABLE							0x01						// enable

#ifdef	BIT_FIELD
#define P0_IO								*(volatile unsigned char *)(BASE_ADDR+0x1202)
	#define P0_IO_P0IO							P0_IO						// P0[7:0] port I/O direction select

#define P1_IO								*(volatile unsigned char *)(BASE_ADDR+0x1212)
	#define P1_IO_P1IO							P1_IO						// P1[7:0] port I/O direction select

#define P2_IO								*(volatile unsigned char *)(BASE_ADDR+0x1222)
	#define P2_IO_P2IO							P2_IO						// P2[7:0] port I/O direction select

#define P3_IO								*(volatile unsigned char *)(BASE_ADDR+0x1232)
	#define P3_IO_P3IO							P3_IO						// P3[7:0] port I/O direction select

#define P4_IO								*(volatile unsigned char *)(BASE_ADDR+0x1242)
#define BF_P4_IO							(*(volatile struct port_pxxBitF *)(BASE_ADDR+0x1242))
	#define P4_IO_P4IO							BF_P4_IO.pxx				// P4[3:0] port I/O direction select
#endif	// end of BIT_FIELD


// Px Port Pull-up Control Register
// NOTE : The bit field be the inhibition that uses it,
//		  because 1 is read at the time of read, in the case that there is reserve bit.
#define R08_PX_PU(pno)						(volatile unsigned char *)(unsigned long)(PORT_BASE_ADDR+0x03+(pno*PORT_NO_OFFSET))

#ifdef	BIT_FIELD
#define P0_PU								*(volatile unsigned char *)(BASE_ADDR+0x1203)
	#define P0_PU_P0PU							P0_PU						// P0[7:0] port pull-up enable

#define P1_PU								*(volatile unsigned char *)(BASE_ADDR+0x1213)
	#define P1_PU_P1PU							P1_PU						// P1[7:0] port pull-up enable

#define P2_PU								*(volatile unsigned char *)(BASE_ADDR+0x1223)
	#define P2_PU_P2PU							P2_PU						// P2[7:0] port pull-up enable

#define P3_PU								*(volatile unsigned char *)(BASE_ADDR+0x1233)
	#define P3_PU_P3PU							P3_PU						// P3[7:0] port pull-up enable

#define P4_PU								*(volatile unsigned char *)(BASE_ADDR+0x1243)
#define BF_P4_PU							(*(volatile struct port_pxxBitF *)(BASE_ADDR+0x1243))
	#define P4_PU_P4PU							BF_P4_PU.pxx				// P4[3:0] port pull-up enable
#endif	// end of BIT_FIELD


// Px Port Schmitt Trigger Control Register
// NOTE : The bit field be the inhibition that uses it,
//		  because 1 is read at the time of read, in the case that there is reserve bit.
#define R08_PX_SM(pno)						(volatile unsigned char *)(unsigned long)(PORT_BASE_ADDR+0x04+(pno*PORT_NO_OFFSET))

#ifdef	BIT_FIELD
#define P0_SM								*(volatile unsigned char *)(BASE_ADDR+0x1204)
	#define P0_SM_P0SM							P0_SM						// P0[7:0] port Schmitt trigger input enable

#define P1_SM								*(volatile unsigned char *)(BASE_ADDR+0x1214)
	#define P1_SM_P1SM							P1_SM						// P1[7:0] port Schmitt trigger input enable

#ifndef	S1C17602
#define P2_SM								*(volatile unsigned char *)(BASE_ADDR+0x1224)
	#define P2_SM_P2SM							P2_SM						// P1[7:0] port Schmitt trigger input enable
#endif	// end of S1C17602
#endif	// end of BIT_FIELD


// Px Port Interrupt Mask Register
#define R08_PX_IMSK(pno)					(volatile unsigned char *)(unsigned long)(PORT_BASE_ADDR+0x05+(pno*PORT_NO_OFFSET))

#ifdef	BIT_FIELD
#define P0_IMSK								*(volatile unsigned char *)(BASE_ADDR+0x1205)
	#define P0_IMSK_P0IE						P0_IMSK					// P0[7:0] port interrupt enable

#define P1_IMSK								*(volatile unsigned char *)(BASE_ADDR+0x1215)
	#define P1_IMSK_P1IE						P1_IMSK					// P1[7:0] port interrupt enable
#endif	// end of BIT_FIELD


// Px Port Interrupt Edge Select Register
#define R08_PX_EDGE(pno)					(volatile unsigned char *)(unsigned long)(PORT_BASE_ADDR+0x06+(pno*PORT_NO_OFFSET))

#ifdef	BIT_FIELD
#define P0_EDGE								*(volatile unsigned char *)(BASE_ADDR+0x1206)
	#define P0_EDGE_P0EDGE						P0_EDGE					// P0[7:0] port interrupt edge select

#define P1_EDGE								*(volatile unsigned char *)(BASE_ADDR+0x1216)
	#define P1_EDGE_P1EDGE						P1_EDGE					// P1[7:0] port interrupt edge select
#endif	// end of BIT_FIELD


// Px Port Interrupt Flag Register
// NOTE : The writing that used the bit field inhibits.
#define R08_PX_IFLG(pno)					(volatile unsigned char *)(unsigned long)(PORT_BASE_ADDR+0x07+(pno*PORT_NO_OFFSET))
	#define	PORT_NOTOCCURRED					0x00						// not occurred
	#define	PORT_OCCURRED						0x01						// occurred
	#define	PORT_INVALID						0x00						// invalid
	#define	PORT_RESET							0x01						// reset

#ifdef	BIT_FIELD
#define P0_IFLG								*(volatile unsigned char *)(BASE_ADDR+0x1207)
	#define P0_IFLG_P0IF						P0_IFLG						// P0[7:0] port interrupt flag

#define P1_IFLG								*(volatile unsigned char *)(BASE_ADDR+0x1217)
	#define P1_IFLG_P1IF						P1_IFLG						// P1[7:0] port interrupt flag
#endif	// end of BIT_FIELD


// Px Port Chattering Filter Control Register
#define R08_PX_CHAT(pno)					(volatile unsigned char *)(unsigned long)(PORT_BASE_ADDR+0x08+(pno*PORT_NO_OFFSET))
	#define PXCF2_SFT							4
	#define CHAT_PXCF2							BIT(0x07, PXCF2_SFT)		// Px[7:4] chattering filter time select
	#define CHAT_PXCF1							BIT(0x07, 0)				// Px[3:0] chattering filter time select

#ifdef	BIT_FIELD
#define P0_CHAT								*(volatile unsigned char *)(BASE_ADDR+0x1208)
#define BF_P0_CHAT							(*(volatile struct port_chatBitF *)(BASE_ADDR + 0x1208))
	#define P0_CHAT_P0CF2						BF_P0_CHAT.pxcf2			// P0[7:4] chattering filter time
	#define P0_CHAT_P0CF1						BF_P0_CHAT.pxcf1			// P0[3:0] chattering filter time
	
#define P1_CHAT								*(volatile unsigned char *)(BASE_ADDR+0x1218)
#define BF_P1_CHAT							(*(volatile struct port_chatBitF *)(BASE_ADDR + 0x1218))
	#define P1_CHAT_P1CF2						BF_P1_CHAT.pxcf2			// P0[7:4] chattering filter time
	#define P1_CHAT_P1CF1						BF_P1_CHAT.pxcf1			// P0[3:0] chattering filter time
#endif	// end of BIT_FIELD


// Px Port Key-Entry Reset Configuration Register
#define R08_PX_KRST(pno)					(volatile unsigned char *)(unsigned long)(PORT_BASE_ADDR+0x09+(pno*PORT_NO_OFFSET))
	#define KRST_P0KRST							BIT(0x03, 0)				// P0 port key-entry reset configuration

#ifdef	BIT_FIELD
#define P0_KRST								*(volatile unsigned char *)(BASE_ADDR+0x1209)
#define BF_P0_KRST							(*(volatile struct port_krstBitF *)(BASE_ADDR+0x1209))
	#define P0_KRST_P0KRST						BF_P0_KRST.p0krst			// P0 port key-entry reset configuration
#endif	// end of BIT_FIELD


// Px Port Inuput Enable Register
// NOTE : The bit field be the inhibition that uses it,
//		  because 1 is read at the time of read, in the case that there is reserve bit.
#define R08_PX_IEN(pno)						(volatile unsigned char *)(unsigned long)(PORT_BASE_ADDR+0x0a+(pno*PORT_NO_OFFSET))

#ifdef	BIT_FIELD
#define P0_IEN								*(volatile unsigned char *)(BASE_ADDR+0x120a)
	#define P0_IEN_P0IEN						P0_IEN						// P0[7:0] port input enable

#define P1_IEN								*(volatile unsigned char *)(BASE_ADDR+0x121a)
	#define P1_IEN_P1IEN						P1_IEN						// P1[7:0] port input enable

#define P2_IEN								*(volatile unsigned char *)(BASE_ADDR+0x122a)
	#define P2_IEN_P2IEN						P2_IEN						// P2[7:0] port input enable

#define P3_IEN								*(volatile unsigned char *)(BASE_ADDR+0x123a)
	#define P3_IEN_P3IEN						P3_IEN						// P3[7:0] port input enable

#define P4_IEN								*(volatile unsigned char *)(BASE_ADDR+0x124a)
#define BF_P4_IEN							(*(volatile struct port_pxxBitF *)(BASE_ADDR+0x124a))
	#define P4_IEN_P4IEN						BF_P4_IEN.pxx				// P4[3:0] port input enable
#endif	// end of BIT_FIELD


#endif	// end of PORT_H_
