/******************************************************************
 * rfc.h
 * 
 * RFC driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef RFC_H_
#define RFC_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct rfc_ctlBitF {
	unsigned int	rfcen	: 1;
#ifdef	S1C17602
	unsigned int	chsel	: 1;
	unsigned int			: 2;
#else
	unsigned int			: 3;
#endif	// end of S1C17602
	unsigned int	smode	: 2;
	unsigned int	evten	: 1;
	unsigned int	conen	: 1;
	unsigned int			: 8;
};

struct rfc_trgBitF {
	unsigned int	sref	: 1;
	unsigned int	ssena	: 1;
	unsigned int	ssenb	: 1;
	unsigned int			: 13;
};

struct rfc_mchBitF {
	unsigned int	mc23_16	: 8;
	unsigned int			: 8;
};

struct rfc_tchBitF {
	unsigned int	tc23_16	: 8;
	unsigned int			: 8;
};

struct rfc_imskBitF {
	unsigned int	erefie	: 1;
	unsigned int	esenaie	: 1;
	unsigned int	esenbie	: 1;
	unsigned int	ovmcie	: 1;
	unsigned int	ovtcie	: 1;
	unsigned int			: 11;
};

struct rfc_iflgBitF {
	unsigned int	erefif	: 1;
	unsigned int	esenaif	: 1;
	unsigned int	esenbif	: 1;
	unsigned int	ovmcif	: 1;
	unsigned int	ovtcif	: 1;
	unsigned int			: 11;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	RFC_BASE_ADDR						(BASE_ADDR+RFC_OFFSET)


/************************************
 ****** The Definition of RFC	 ****
 ******                          ****
 ************************************/
// RFC Control Register
#define	R16_RFC_CTL							(volatile unsigned short *)(unsigned long)(RFC_BASE_ADDR+0x00)
	#define	CONEN_SFT							7
	#define	EVTEN_SFT							6
	#define	SMODE_SFT							4
#ifdef	S1C17602
	#define	CHSEL_SFT							1
#endif	// end of S1C17602
	#define	RFCEN_SFT							0
	#define	CONEN								BIT(0x0001, CONEN_SFT)		// Continuous Oscillation Enable
		#define	RFC_BIT_DISABLE						0x00						// disable
		#define	RFC_BIT_ENABLE						0x01						// enable
	#define	EVTEN								BIT(0x0001, EVTEN_SFT)		// Event Counter Mode Enable
	#define	SMODE								BIT(0x0003, SMODE_SFT)		// Sensor Oscillation Mode
#ifdef	S1C17602
	#define	CHSEL								BIT(0x0001, CHSEL_SFT)		// Conversion Channel Select
#endif	// end of S1C17602
	#define	RFCEN								BIT(0x0001, RFCEN_SFT)		// RFC Enable

#ifdef	BIT_FIELD
#define RFC_CTL								*(volatile unsigned short *)(BASE_ADDR+0x13a0)
#define BF_RFC_CTL							(*(volatile struct rfc_ctlBitF *)(BASE_ADDR+0x13a0))
	#define RFC_CTL_CONEN						BF_RFC_CTL.conen			// Continuous oscillation enable
	#define RFC_CTL_EVTEN						BF_RFC_CTL.evten			// Event counter mode enable
	#define RFC_CTL_SMODE						BF_RFC_CTL.smode			// Sensor oscillation mode select
#ifdef	S1C17602
	#define RFC_CTL_CHSEL						BF_RFC_CTL.chsel			// conversion Channel select
#endif	// end of S1C17602
	#define RFC_CTL_RFCEN						BF_RFC_CTL.rfcen			// RFC enable
#endif	// end of BIT_FIELD


// RFC Oscillation Start Register
#define	R16_RFC_TRG							(volatile unsigned short *)(unsigned long)(RFC_BASE_ADDR+0x02)
	#define	SSENB_SFT							2
	#define	SSENA_SFT							1
	#define	SREF_SFT							0
	#define	SSENB								BIT(0x0001, SSENB_SFT)		// Sensor B Oscillation Start Trigger
		#define	RFC_STOP							0x00						// stop
		#define	RFC_START							0x01						// start
		#define	RFC_RUN								0x01						// run
	#define	SSENA								BIT(0x0001, SSENA_SFT)		// Sensor A Oscillation Start Trigger
	#define	SREF								BIT(0x0001, SREF_SFT)		// Reference Oscillation Start Trigger

#ifdef	BIT_FIELD
#define RFC_TRG								*(volatile unsigned short *)(BASE_ADDR+0x13a2)
#define BF_RFC_TRG							(*(volatile struct rfc_trgBitF *)(BASE_ADDR+0x13a2))
	#define RFC_TRG_SSENB						BF_RFC_TRG.ssenb			// Sensor B oscillation Start trigger
	#define RFC_TRG_SSENA						BF_RFC_TRG.ssena			// Sensor A oscillation Start trigger
	#define RFC_TRG_SREF						BF_RFC_TRG.sref				// Reference dc oscillation Start trigger 
#endif	// end of BIT_FIELD


// RFC measurement Counter LSB Register
#define	R16_RFC_MCL							(volatile unsigned short *)(unsigned long)(RFC_BASE_ADDR+0x04)

#ifdef	BIT_FIELD
#define RFC_MCL								*(volatile unsigned short *)(BASE_ADDR+0x13a4)
	#define RFC_MCL_MC							RFC_MCL						// Measurement Counter data [15:0]
#endif	// end of BIT_FIELD


// RFC measurement Counter MSB Register
#define	R16_RFC_MCH							(volatile unsigned short *)(unsigned long)(RFC_BASE_ADDR+0x06)
	#define	MC23_16_SFT							0
	#define	MC23_16								BIT(0x00ff, MC23_16_SFT)	// Measurement Counter Data

#ifdef	BIT_FIELD
#define RFC_MCH								*(volatile unsigned short *)(BASE_ADDR+0x13a6)
#define BF_RFC_MCH							(*(volatile struct rfc_mchBitF *)(BASE_ADDR+0x13a6))
	#define RFC_MCH_MC							BF_RFC_MCH.mc23_16			// Measurement Counter data [23:16]
#endif	// end of BIT_FIELD


// RFC Time Base Counter LSB Register
#define	R16_RFC_TCL							(volatile unsigned short *)(unsigned long)(RFC_BASE_ADDR+0x08)

#ifdef	BIT_FIELD
#define RFC_TCL								*(volatile unsigned short *)(BASE_ADDR+0x13a8)
	#define RFC_TCL_TC							RFC_TCL						// Time Base Counter data [15:0]
#endif	// end of BIT_FIELD


// RFC Time Base Counter MSB Register
#define	R16_RFC_TCH							(volatile unsigned short *)(unsigned long)(RFC_BASE_ADDR+0x0a)
	#define	TC23_16_SFT							0
	#define	TC23_16								BIT(0x00ff, TC23_16_SFT)	// Time Base Counter Data

#ifdef	BIT_FIELD
#define RFC_TCH								*(volatile unsigned short *)(BASE_ADDR+0x13aa)
#define BF_RFC_TCH							(*(volatile struct rfc_tchBitF *)(BASE_ADDR+0x13aa))
	#define RFC_TCH_TC							BF_RFC_TCH.tc23_16			// Time Base Counter data [23:16]
#endif	// end of BIT_FIELD


// RFC Interrupt Mask Register
#define	R16_RFC_IMSK						(volatile unsigned short *)(unsigned long)(RFC_BASE_ADDR+0x0c)
	#define	OVTCIE_SFT							4
	#define	OVMCIE_SFT							3
	#define	ESENBIE_SFT							2
	#define	ESENAIE_SFT							1
	#define	EREFIE_SFT							0
	#define	OVTCIE								BIT(0x01, OVTCIE_SFT)		// Timer Base Counter Over Flow Error Interrupt Enable
	#define	OVMCIE								BIT(0x01, OVMCIE_SFT)		// Measurement Counter Over Flow Error Interrupt Enable
	#define	ESENBIE								BIT(0x01, ESENBIE_SFT)		// Sensor B Oscillation End Interrupt Enable
	#define	ESENAIE								BIT(0x01, ESENAIE_SFT)		// Sensor A Oscillation End Interrupt Enable
	#define	EREFIE								BIT(0x01, EREFIE_SFT)		// Reference Oscillation End Interrupt Enable
		#define	RFC_IMSK_MASK						(OVTCIE | OVMCIE | ESENBIE | ESENAIE | EREFIE)
																				// interrupt mask data

#ifdef	BIT_FIELD
#define RFC_IMSK							*(volatile unsigned short *)(BASE_ADDR+0x13ac)
#define BF_RFC_IMSK							(*(volatile struct rfc_imskBitF *)(BASE_ADDR+0x13ac))
	#define RFC_IMSK_OVTCIE						BF_RFC_IMSK.ovtcie			// Time base Counter Overflow error interrupt enable
	#define RFC_IMSK_OVMCIE						BF_RFC_IMSK.ovmcie			// Mesurement Counter Overflow error interrupt enable
	#define RFC_IMSK_ESENBIE					BF_RFC_IMSK.esenbie			// Sensor B oscillation end interrupt enable
	#define RFC_IMSK_ESENAIE					BF_RFC_IMSK.esenaie			// Sensor A oscillation end interrupt enable
	#define RFC_IMSK_EREFIE						BF_RFC_IMSK.erefie			// Reference oscillation end interrupt enable
#endif	// end of BIT_FIELD


// RFC Interrupt Flag Register
#define	R16_RFC_IFLG						(volatile unsigned short *)(unsigned long)(RFC_BASE_ADDR+0x0e)
	#define	OVTCIF_SFT							4
	#define	OVMCIF_SFT							3
	#define	ESENBIF_SFT							2
	#define	ESENAIF_SFT							1
	#define	EREFIF_SFT							0
	#define	OVTCIF								BIT(0x01, OVTCIF_SFT)		// Timer Base Counter Over Flow Error Flag
		#define	RFC_INVLID							0x00						// invlid
		#define	RFC_RESET							0x01						// reset
		#define	RFC_NOTOCCURRED						0x00						// not occurred
		#define	RFC_OCCURRED						0x01						// occurred
	#define	OVMCIF								BIT(0x01, OVMCIF_SFT)		// Measurement Counter Over Flow Error Flag
	#define	ESENBIF								BIT(0x01, ESENBIF_SFT)		// Sensor B Oscillation End Flag
	#define	ESENAIF								BIT(0x01, ESENAIF_SFT)		// Sensor A Oscillation End Flag
	#define	EREFIF								BIT(0x01, EREFIF_SFT)		// Reference Oscillation End Flag
		#define	RFC_IFLG_MASK						(OVTCIF | OVMCIF | ESENBIF | ESENAIF | EREFIF)
																				// interrupt flag mask data

#ifdef	BIT_FIELD
#define RFC_IFLG							*(volatile unsigned short *)(BASE_ADDR+0x13ae)
#define BF_RFC_IFLG							(*(volatile struct rfc_iflgBitF *)(BASE_ADDR+0x13ae))
	#define RFC_IFLG_OVTCIF						BF_RFC_IFLG.ovtcif			// Time base Counter Overflow error interrupt flag
	#define RFC_IFLG_OVMCIF						BF_RFC_IFLG.ovmcif			// Mesurement Counter Overflow error interrupt flag
	#define RFC_IFLG_ESENBIF					BF_RFC_IFLG.esenbif			// Sensor B oscillation end interrupt flag
	#define RFC_IFLG_ESENAIF					BF_RFC_IFLG.esenaif			// Sensor A oscillation end interrupt flag
	#define RFC_IFLG_EREFIF						BF_RFC_IFLG.erefif			// Reference oscillation end interrupt flag
#endif	// end of BIT_FIELD


#endif	// end of RFC_H_
