/******************************************************************
 * svd.h
 * 
 * SVD driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef SVD_H_
#define SVD_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct svd_enBitF {
	unsigned int	svden	: 1;
	unsigned int			: 7;
};

struct svd_cmpBitF {
	unsigned int	svdc	: 4;
	unsigned int			: 4;
};

struct svd_rsltBitF {
	unsigned int	svddt	: 1;
	unsigned int			: 7;
};

struct svd_imskBitF {
	unsigned int	svdie	: 1;
	unsigned int			: 7;
};

struct svd_iflgBitF {
	unsigned int	svdif	: 1;
	unsigned int			: 7;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	SVD_BASE_ADDR						(BASE_ADDR+SVD_OFFSET)


/***********************************************
 ****** The Definition of SVD Circuit **********
 ****** [SVD]                         **********
 ***********************************************/
// SVD Enable Register
#define	R08_SVD_EN							(volatile unsigned char *)(unsigned long)(SVD_BASE_ADDR+0x00)
	#define	SVDEN_SFT							0
	#define	SVDEN								BIT(0x01, SVDEN_SFT)		// SVD Enable
		#define	SVD_DISABLE						0x00							// disable
		#define	SVD_ENABLE						0x01							// enable

#ifdef	BIT_FIELD
#define SVD_EN								*(volatile unsigned char *)(BASE_ADDR+0x1100)
#define BF_SVD_EN							(*(volatile struct svd_enBitF *)(BASE_ADDR+0x1100))
	#define SVD_EN_SVDEN						BF_SVD_EN.svden				//SVD enable
#endif	// end of BIT_FIELD


// SVD Compare Voltage Register
#define	R08_SVD_CMP							(volatile unsigned char *)(unsigned long)(SVD_BASE_ADDR+0x01)
	#define	SVDC_SFT							0
	#define	SVDC								BIT(0x0f, SVDC_SFT)			// SVD Compare Voltage Select

#ifdef	BIT_FIELD
#define SVD_CMP								*(volatile unsigned char *)(BASE_ADDR+0x1101)
#define BF_SVD_CMP							(*(volatile struct svd_cmpBitF *)(BASE_ADDR+0x1101))
	#define SVD_CMP_SVDC						BF_SVD_CMP.svdc				// SVD compare voltage
#endif	// end of BIT_FIELD


// SVD Detection Result Register
#define	R08_SVD_RSLT						(volatile unsigned char *)(unsigned long)(SVD_BASE_ADDR+0x02)
	#define	SVDDT_SFT							0
	#define	SVDDT								BIT(0x01, SVDDT_SFT)		// SVD Detection Result
		#define	SVD_NORMAL						0x00							// normal
		#define	SVD_LOW							0x01							// low

#ifdef	BIT_FIELD
#define SVD_RSLT							*(volatile unsigned char *)(BASE_ADDR+0x1102)
#define BF_SVD_RSLT							(*(volatile struct svd_rsltBitF *)(BASE_ADDR+0x1102))
	#define SVD_RSLT_SVDDT						BF_SVD_RSLT.svddt			// SVD detection result
#endif	// end of BIT_FIELD


// SVD Interrupt Mask Register
#define	R08_SVD_IMSK						(volatile unsigned char *)(unsigned long)(SVD_BASE_ADDR+0x03)
	#define	SVDIE_SFT							0
	#define	SVDIE								BIT(0x01, SVDIE_SFT)		// SVD Interrupt Enable

#ifdef	BIT_FIELD
#define SVD_IMSK							*(volatile unsigned char *)(BASE_ADDR+0x1103)
#define BF_SVD_IMSK							(*(volatile struct svd_imskBitF *)(BASE_ADDR+0x1103))
	#define SVD_IMSK_SVDIE						BF_SVD_IMSK.svdie			// SVD interrupt enable
#endif	// end of BIT_FIELD


// SVD Interrupt Flag Register
#define	R08_SVD_IFLG						(volatile unsigned char *)(unsigned long)(SVD_BASE_ADDR+0x04)
	#define	SVDIF_SFT							0
	#define	SVDIF								BIT(0x01, SVDIF_SFT)		// SVD Interrupt Flag
		#define	SVD_INVALID						0x00							// invalid
		#define	SVD_RESET						0x01							// reset
		#define	SVD_NOTOCCURRED					0x00							// not occurred
		#define	SVD_OCCURRED					0x01							// occurred

#ifdef	BIT_FIELD
#define SVD_IFLG							*(volatile unsigned char *)(BASE_ADDR+0x1104)
#define BF_SVD_IFLG							(*(volatile struct svd_iflgBitF *)(BASE_ADDR+0x1104))
	#define SVD_IFLG_SVDIF						BF_SVD_IFLG.svdif			// SVD interrupt flag  (read only)
#endif	// end of BIT_FIELD


#endif	// end of SVD_H_
