/******************************************************************
 * t16.h
 * 
 * 16-bit timer driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef	T16_H_
#define	T16_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct t16_clkBitF {
	unsigned int	df		: 4;
	unsigned int			: 12;
};

struct t16_ctlBitF {
	unsigned int	prun	: 1;
	unsigned int	preser	: 1;
	unsigned int			: 2;
	unsigned int	trmd	: 1;
	unsigned int			: 3;
	unsigned int	cksl	: 2;
	unsigned int	ckactv	: 1;
	unsigned int			: 5;
};

struct t16_intBitF {
	unsigned int	t16if	: 1;
	unsigned int			: 7;
	unsigned int	t16ie	: 1;
	unsigned int			: 7;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	T16_BASE_ADDR						(BASE_ADDR+T16_OFFSET)


/***********************************************
 ****** The Definition of 16-bit Timer *********
 ****** [T16]                          *********
 ***********************************************/
// 16-bit Timer Ch.x Input Clock Select Register
#define	R16_T16_CLK(ch)						(volatile unsigned short *)(unsigned long)(T16_BASE_ADDR+0x00+(ch*T16_CHOFFSET))
	#define	DF_SFT								0
	#define	DF									BIT(0x000f, DF_SFT)			// Timer input clock select

#ifdef	BIT_FIELD
#define T16_CLK0							*(volatile unsigned short *)(BASE_ADDR+0x0220)
#define BF_T16_CLK0							(*(volatile struct t16_clkBitF *)(BASE_ADDR+0x0220))
	#define T16_CLK0_DF							BF_T16_CLK0.df				// Timer input clock select

#define T16_CLK1							*(volatile unsigned short *)(BASE_ADDR+0x0240)
#define BF_T16_CLK1							(*(volatile struct t16_clkBitF *)(BASE_ADDR+0x0240))
	#define T16_CLK1_DF							BF_T16_CLK1.df				// Timer input clock select

#define T16_CLK2							*(volatile unsigned short *)(BASE_ADDR+0x0260)
#define BF_T16_CLK2							(*(volatile struct t16_clkBitF *)(BASE_ADDR+0x0260))
	#define T16_CLK2_DF							BF_T16_CLK2.df				// Timer input clock select
#endif	// end of BIT_FIELD


// 16-bit Timer Ch.x Reload Data Register
#define	R16_T16_TR(ch)						(volatile unsigned short *)(unsigned long)(T16_BASE_ADDR+0x02+(ch*T16_CHOFFSET))

#ifdef	BIT_FIELD
#define T16_TR0								*(volatile unsigned short *)(BASE_ADDR+0x0222)
	#define T16_TR0_TR							T16_TR0						// 16-bit timer reload data

#define T16_TR1								*(volatile unsigned short *)(BASE_ADDR+0x0242)
	#define T16_TR1_TR							T16_TR1						// 16-bit timer reload data

#define T16_TR2								*(volatile unsigned short *)(BASE_ADDR+0x0262)
	#define T16_TR2_TR							T16_TR2						// 16-bit timer reload data
#endif	// end of BIT_FIELD


// 16-bit Timer Ch.x Counter Data Register
#define	R16_T16_TC(ch)						(volatile unsigned short *)(unsigned long)(T16_BASE_ADDR+0x04+(ch*T16_CHOFFSET))

#ifdef	BIT_FIELD
#define T16_TC0								*(volatile unsigned short *)(BASE_ADDR+0x0224)
	#define T16_TC0_TC							T16_TC0						// 16-bit timer counter data

#define T16_TC1								*(volatile unsigned short *)(BASE_ADDR+0x0244)
	#define T16_TC1_TC							T16_TC1						// 16-bit timer counter data

#define T16_TC2								*(volatile unsigned short *)(BASE_ADDR+0x0264)
	#define T16_TC2_TC							T16_TC2						// 16-bit timer counter data
#endif	// end of BIT_FIELD


// 16-bit Timer Ch.x Control Register
#define	R16_T16_CTL(ch)						(volatile unsigned short *)(unsigned long)(T16_BASE_ADDR+0x06+(ch*T16_CHOFFSET))
	#define	CKACTV_SFT							10
	#define	CKSL_SFT							8
	#define	TRMD_SFT							4
	#define	PRESER_SFT							1
	#define	PRUN_SFT							0
	#define	CKACTV								BIT(0x0001, CKACTV_SFT)		// External clock active level select
		#define	T16_LOW								0x0000						// low
		#define	T16_HIGH							0x0001						// high
	#define	CKSL								BIT(0x0003, CKSL_SFT)		// Input clock and pulse width measurement mode select
	#define	TRMD								BIT(0x0001, TRMD_SFT)		// Count mode select
		#define	T16_REPEAT							0x0000						// repeat
		#define	T16_ONESHOT							0x0001						// one shot
	#define	PRESER								BIT(0x0001, PRESER_SFT)		// Timer reset
		#define	T16_IGNORED							0x0000						// ignored
		#define	T16_RESET							0x0001						// reset
	#define	PRUN								BIT(0x0001, PRUN_SFT)		// Timer run/stop control
		#define	T16_STOP							0x0000						// stop
		#define	T16_RUN								0x0001						// run

#ifdef	BIT_FIELD
#define T16_CTL0							*(volatile unsigned short *)(BASE_ADDR+0x0226)
#define BF_T16_CTL0							(*(volatile struct t16_ctlBitF *)(BASE_ADDR+0x0226))
	#define T16_CTL0_CKACTV						BF_T16_CTL0.ckactv			// External clock active level select
	#define T16_CTL0_CKSL						BF_T16_CTL0.cksl			// Input clock and pulse width measurement mode select 
	#define T16_CTL0_TRMD						BF_T16_CTL0.trmd			// Count mode select
	#define T16_CTL0_PRESER						BF_T16_CTL0.preser			// Timer reset
	#define T16_CTL0_PRUN						BF_T16_CTL0.prun			// Timer run/stop controle

#define T16_CTL1							*(volatile unsigned short *)(BASE_ADDR+0x0246)
#define BF_T16_CTL1							(*(volatile struct t16_ctlBitF *)(BASE_ADDR+0x0246))
	#define T16_CTL1_CKACTV						BF_T16_CTL1.ckactv			// External clock active level select
	#define T16_CTL1_CKSL						BF_T16_CTL1.cksl			// Input clock and pulse width measurement mode select
	#define T16_CTL1_TRMD						BF_T16_CTL1.trmd			// Count mode select
	#define T16_CTL1_PRESER						BF_T16_CTL1.preser			// Timer reset
	#define T16_CTL1_PRUN						BF_T16_CTL1.prun			// Timer run/stop controle

#define T16_CTL2							*(volatile unsigned short *)(BASE_ADDR+0x0266)
#define BF_T16_CTL2							(*(volatile struct t16_ctlBitF *)(BASE_ADDR+0x0266))
	#define T16_CTL2_CKACTV						BF_T16_CTL2.ckactv			// External clock active level select
	#define T16_CTL2_CKSL						BF_T16_CTL2.cksl			// Input clock and pulse width measurement mode select
	#define T16_CTL2_TRMD						BF_T16_CTL2.trmd			// Count mode select
	#define T16_CTL2_PRESER						BF_T16_CTL2.preser			// Timer reset
	#define T16_CTL2_PRUN						BF_T16_CTL2.prun			// Timer run/stop controle
#endif	// end of BIT_FIELD


// 16-bit Timer Ch.x Interrupt Control Register
#define	R16_T16_INT(ch)						(volatile unsigned short *)(unsigned long)(T16_BASE_ADDR+0x08+(ch*T16_CHOFFSET))
	#define	T16IE_SFT							8
	#define	T16IF_SFT							0
	#define	T16IE								BIT(0x0001, T16IE_SFT)		// 16-bit Timer Interrupt enable
		#define T16_DISABLE							0x0000						// disable
		#define T16_ENABLE							0x0001						// enable
	#define	T16IF								BIT(0x0001, T16IF_SFT)		// 16-bit Timer Interrupt flag
		#define T16_NOTOCCURRED						0x0000						// not occurred
		#define T16_OCCURRED						0x0001						// occurred

#ifdef	BIT_FIELD
#define T16_INT0							*(volatile unsigned short *)(BASE_ADDR+0x0228)
#define BF_T16_INT0							(*(volatile struct t16_intBitF *)(BASE_ADDR+0x0228))
	#define T16_INT0_T16IE						BF_T16_INT0.t16ie			// 16-bit Timer ch.0 Interrupt enable
	#define T16_INT0_T16IF						BF_T16_INT0.t16if			// 16-bit Timer ch.0 Interrupt flag

#define T16_INT1							*(volatile unsigned short *)(BASE_ADDR+0x0248)
#define BF_T16_INT1							(*(volatile struct t16_intBitF *)(BASE_ADDR+0x0248))
	#define T16_INT1_T16IE						BF_T16_INT1.t16ie			// 16-bit Timer ch.1 Interrupt enable
	#define T16_INT1_T16IF						BF_T16_INT1.t16if			// 16-bit Timer ch.1 Interrupt flag

#define T16_INT2							*(volatile unsigned short *)(BASE_ADDR+0x0268)
#define BF_T16_INT2							(*(volatile struct t16_intBitF *)(BASE_ADDR+0x0268))
	#define T16_INT2_T16IE						BF_T16_INT2.t16ie			// 16-bit Timer ch.2 Interrupt enable
	#define T16_INT2_T16IF						BF_T16_INT2.t16if			// 16-bit Timer ch.2 Interrupt flag
#endif	// end of BIT_FIELD


#endif	// end of T16_H_
