/******************************************************************
 * wdt.h
 * 
 * watchdog timer driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef WDT_H_
#define WDT_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct wdt_ctlBitF {
	unsigned int	wdtrun	: 4;
	unsigned int	wdtrst	: 1;
	unsigned int			: 3;
};

struct wdt_stBitF {
	unsigned int	wdtst	: 1;
	unsigned int	wdtmd	: 1;
	unsigned int			: 6;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	WDT_BASE_ADDR						(BASE_ADDR+WDT_OFFSET)


/***********************************************
 ****** The Definition of Watchdog Timer *******
 ****** [WDT]                            *******
 ***********************************************/
// Watchdog Timer Controle Register
#define	R08_WDT_CTL							(volatile unsigned char *)(unsigned long)(WDT_BASE_ADDR+0x00)
	#define	WDTRST_SFT							4
	#define	WDTRUN_SFT							0
	#define	WDTRST								BIT(0x01, WDTRST_SFT)		// Watchdog Timer Reset
		#define	WDT_INVALID							0x00						// invalid
		#define	WDT_RESET							0x01						// reset
	#define	WDTRUN								BIT(0x0f, WDTRUN_SFT)		// Watchdog Timer Run/Stop Control
		#define	WDT_STOP							0x0a						// stop
		#define	WDT_RUN								0x00						// run

#ifdef	BIT_FIELD
#define WDT_CTL								*(volatile unsigned char *)(BASE_ADDR+0x1040)
#define BF_WDT_CTL							(*(volatile struct wdt_ctlBitF *)(BASE_ADDR+0x1040))
	#define WDT_CTL_WDTRST						BF_WDT_CTL.wdtrst			// Watchdog timer reset
	#define WDT_CTL_WDTRUN						BF_WDT_CTL.wdtrun			// Watchdog timer run/stop control
#endif	// end of BIT_FIELD


// Watchdog Timer Status Register
#define	R08_WDT_ST							(volatile unsigned char *)(unsigned long)(WDT_BASE_ADDR+0x01)
	#define	WDTMD_SFT							1
	#define	WDTST_SFT							0
	#define	WDTMD								BIT(0x01, WDTMD_SFT)		// NMI/Reset Mode Select
		#define	WDT_NMI								0x00						// NMI
	#define	WDTST								BIT(0x01, WDTST_SFT)		// NMI Status
		#define	WDT_NOTOCCURRED						0x00						// not occurred
		#define	WDT_OCCURRED						0x01						// occurred

#ifdef	BIT_FIELD
#define WDT_ST								*(volatile unsigned char *)(BASE_ADDR+0x1041)
#define BF_WDT_ST							(*(volatile struct wdt_stBitF *)(BASE_ADDR+0x1041))
	#define WDT_ST_WDTMD						BF_WDT_ST.wdtmd				// NMI/Reset mode select
	#define WDT_ST_WDTST						BF_WDT_ST.wdtst				// NMI status
#endif	// end of BIT_FIELD


#endif	// end of WDT_H_
