/******************************************************************
 * s1c17611_peripheral.h
 *
 * S1C17611 peripheral definition
 *
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef S1C17611_PERIPHERAL_H_
#define S1C17611_PERIPHERAL_H_

#define	BIT_FIELD

#include <itc.h>


/*****************************************************************************/
/* Basa address definition of I/O Area										 */
/*****************************************************************************/
#define BASE_ADDR							0x004000


/*****************************************************************************/
/* Register access macro													 */
/*****************************************************************************/
#define RegRead(reg)						(*(reg))
#define RegWrite(reg, value)				(*(reg)  =  (value))
#define RegSet(reg, value)					(*(reg) |=  (value))
#define RegClear(reg, value)				(*(reg) &= ~(value))
#define RegModify(reg, mask, value)			(*(reg) = (RegRead((reg))&~(mask)) | value )

#define BIT(bit, sft)						(bit << sft)

/*****************************************************************************/
/* 0x4020			Prescaler(PSC)											 */
/*****************************************************************************/
#define PSC_OFFSET							(0x0020)

#define PE_PSC


/*****************************************************************************/
/* 0x4100-0x4125	UART(with IrDA)											 */
/*****************************************************************************/
#define UART_OFFSET							(0x0100)
#define UART_CHOFFSET						(0x0020)

#define PE_UART
#define PE_UART_OSC3
#define PE_UART_IOSC

#define	UART_CHANNEL1
#define	UART_INTLVL_CH0						R08_ITC_LV6L					// Ch0 interrupt level


/*****************************************************************************/
/* 0x4200-0x4208	8-bit Timer (with Fine Mode) Ch.0(T8F)					 */
/*****************************************************************************/
#define T8F_OFFSET							(0x0200)
#define T8F_CHOFFSET						(0x0080)

#define PE_T8F

#define	T8F_CHANNEL1

#define	T8F_INTLVL							R08_ITC_LV4L					// interrupt level


/*****************************************************************************/
/* 0x4220-0x4268	16-bit Timer(T16)										 */
/*****************************************************************************/
#define T16_OFFSET							(0x0220)
#define T16_CHOFFSET						(0x0020)

#define PE_T16

#define	T16_CHANNEL3
#define T16_INTLVL_CH0						R08_ITC_LV4H					// Ch0 interrupt level
#define T16_INTLVL_CH1						R08_ITC_LV5L					// Ch1 interrupt level
#define T16_INTLVL_CH2						R08_ITC_LV5H					// Ch2 interrupt level


/*****************************************************************************/
/* 0x4306-0x4318	Interrupt Controller(ITC)								 */
/*****************************************************************************/
#define ITC_OFFSET							(0x0300)


/*****************************************************************************/
/* 0x4320-0x4326	SPI														 */
/*****************************************************************************/
#define SPI_OFFSET							(0x0320)
#define	SPI_OFFSET2							(0x0360)
#define	SPI_CHOFFSET						(0x0020)

#define PE_SPI
#define PE_SPI_MASTER
#define PE_SPI_SLAVE

#define	SPI_CHANNEL1
#define	SPI_INTLVL_CH0						R08_ITC_LV7L					// Ch0 interrupt level


/*****************************************************************************/
/* 0x4340-0x4346	I2C Master(I2CM)										 */
/*****************************************************************************/
#define I2CM_OFFSET							(0x0340)

#define PE_I2CM

#define	I2CM_INTLVL							R08_ITC_LV7H					// interrupt level


/*****************************************************************************/
/* 0x4360-0x436c	I2C Slave(I2CS)											 */
/*****************************************************************************/
#define I2CS_OFFSET							(0x0360)

#define PE_I2CS

#define	I2CS_INTLVL							R08_ITC_LV6H					// interrupt level


/*****************************************************************************/
/* 0x5000-0x5003	Clock Timer(CT)											 */
/*****************************************************************************/
#define CT_OFFSET							(0x1000)

#define PE_CT

#define	CT_INTLVL							R08_ITC_LV1H					// interrupt level


/*****************************************************************************/
/* 0x5020-0x5023	Stopwatch Timer(SWT)									 */
/*****************************************************************************/
#define SWT_OFFSET							(0x1020)

#define PE_SWT

#define	SWT_INTLVL							R08_ITC_LV1L					// interrupt level


/*****************************************************************************/
/* 0x5040-0x5041	Watchdog Timer(WDT)										 */
/*****************************************************************************/
#define WDT_OFFSET							(0x1040)

#define PE_WDT


/*****************************************************************************/
/* 0x5060-0x5067	Oscillator(OSC)											 */
/*****************************************************************************/
#define OSC_OFFSET							(0x1060)

#define PE_OSC


/*****************************************************************************/
/* 0x5080-0x5081	Clock Generator(CLG)									 */
/*****************************************************************************/
#define CLG_OFFSET							(0x1080)

#define PE_CLG


/*****************************************************************************/
/* 0x50a0-0x50a6	LCD Driver(LCD)											 */
/*****************************************************************************/
#define LCD_OFFSET							(0x10a0)

#define PE_LCD

#define LCD_SEG_8
#define LCD_COM_8
#define SET_LCD_DUTY						LCD_DUTY_8

#define	LCD_INTLVL							R08_ITC_LV3L					// interrupt level

#define	LCD_RAM_ADDR						(0x53c0)


/*****************************************************************************/
/* 0x50c0-0x50c4	8-bit OSC1 Timer(T8OSC1)								 */
/*****************************************************************************/
#define T8OSC1_OFFSET						(0x10c0)

#define PE_T8OSC1

#define	T8O_INTLVL							R08_ITC_LV2L					// interrupt level


/*****************************************************************************/
/* 0x5100-0x5104	SVD Circuit(SVD)										 */
/*****************************************************************************/
#define SVD_OFFSET							(0x1100)

#define PE_SVD

#define	SVD_INTLVL							R08_ITC_LV2H					// interrupt level


/*****************************************************************************/
/* 0x5120			Power Generator(VD1)									 */
/*****************************************************************************/
#define VD1_OFFSET							(0x1120)

#define PE_VD1

/*****************************************************************************/
/* 0x5200-0x5213	P Port(PORT) & Port MUX(MUX)							 */
/*****************************************************************************/
#define PORT_OFFSET							(0x1200)
#define PORT_NO_OFFSET						(0x0010)

#define PE_PORT																// PORT valid
#define	PORT_MAX_P2

#define PORT_NUMBER							(19)							// I/O port number

#define PORT_RSVMSK_P0						(0xff)							// P00-P07
#define PORT_RSVMSK_P1						(0xff)							// P10-P17
#define PORT_RSVMSK_P2						(0x07)							// P20-P27
#define PORT_RSVMSK_P3						(0x00)							// P30-P37
#define PORT_RSVMSK_P4						(0x00)							// P40-P43

#define PORT_SMT_MAX						(0x02)							// schmitt trigger port MAX number
#define PORT_SMTMSK_P0						(0xff)							// P00-P07
#define PORT_SMTMSK_P1						(0xff)							// P10-P17
#define PORT_SMTMSK_P2						(0x07)							// P20-P24
#define PORT_SMTMSK_P3						(0x00)							//
#define PORT_SMTMSK_P4						(0x00)							//

#define PORT_INT_MAX						(0x01)							// interrupt port MAX number

#define PORT_INTLVL_P0						R08_ITC_LV0L					// P0 interrupt level
#define PORT_INTLVL_P1						R08_ITC_LV0H					// P1 interrupt level

/*****************************************************************************/

#define MUX_OFFSET							(0x12a0)

#define PE_MUX

// ADC port
#define	MUX_PORT_ADTRG						R08_P1H_PMUX					// #ADTRG port
#define	MUX_MASK_ADTRG						P14MUX							//
#define	MUX_ADC_ADTRG						xADTRG							//

#define	MUX_PORT_AIN0						R08_P0H_PMUX					// AIN0 port
#define	MUX_MASK_AIN0						P06MUX							//
#define	MUX_ADC_AIN0						AIN0							//

#define	MUX_PORT_AIN1						R08_P0H_PMUX					// AIN1 port
#define	MUX_MASK_AIN1						P05MUX							//
#define	MUX_ADC_AIN1						AIN1							//

#define	MUX_PORT_AIN2						R08_P0H_PMUX					// AIN2 port
#define	MUX_MASK_AIN2						P04MUX							//
#define	MUX_ADC_AIN2						AIN2							//

#define	MUX_PORT_AIN3						R08_P0L_PMUX					// AIN3 port
#define	MUX_MASK_AIN3						P03MUX							//
#define	MUX_ADC_AIN3						AIN3							//

// SPI port
#define	MUX_PORT_SPICLK0					R08_P2L_PMUX					// SPICLK port
#define	MUX_MASK_SPICLK0					P20MUX							//
#define	MUX_SPI_SPICLK0						SPICLK							//

#define	MUX_PORT_SDO0						R08_P1H_PMUX					// SDO port
#define	MUX_MASK_SDO0						P17MUX							//
#define	MUX_SPI_SDO0						SDO								//

#define	MUX_PORT_SDI0						R08_P1H_PMUX					// SDI port
#define	MUX_MASK_SDI0						P16MUX							//
#define	MUX_SPI_SDI0						SDI								//

#define	MUX_PORT_SPISS0						R08_P1H_PMUX					// #SPISS port
#define	MUX_MASK_SPISS0						P15MUX							//
#define	MUX_SPI_SPISS0						xSPISS							//

// UART port
#define	MUX_PORT_SOUT0						R08_P1L_PMUX					// SOUT port
#define	MUX_MASK_SOUT0						P13MUX							//
#define	MUX_UART_SOUT0						SOUT							//

#define	MUX_PORT_SIN0						R08_P1H_PMUX					// SIN port
#define	MUX_MASK_SIN0						P14MUX							//
#define	MUX_UART_SIN0						SIN								//

#define	MUX_PORT_SCLK0						R08_P1L_PMUX					// SCLK port
#define	MUX_MASK_SCLK0						P12MUX							//
#define	MUX_UART_SCLK0						SCLK							//

// RFC port
#define	MUX_PORT_RFIN0						R08_P0H_PMUX					// RFIN0 port
#define	MUX_MASK_RFIN0						P07MUX							//
#define	MUX_RFC_RFIN0						RFIN0							//

#define	MUX_PORT_REF0						R08_P1L_PMUX					// REF0 port
#define	MUX_MASK_REF0						P10MUX							//
#define	MUX_RFC_REF0						REF0							//

#define	MUX_PORT_SENA0						R08_P1L_PMUX					// SENA0 port
#define	MUX_MASK_SENA0						P11MUX							//
#define	MUX_RFC_SENA0						SENA0							//

#define	MUX_PORT_SENB0						R08_P1L_PMUX					// SENB0 port
#define	MUX_MASK_SENB0						P12MUX							//
#define	MUX_RFC_SENB0						SENB0							//

#define	MUX_PORT_RFCLKO						R08_P0L_PMUX					// RFCLKO port
#define	MUX_MASK_RFCLKO						P02MUX							//
#define	MUX_RFC_RFCLKO						RFCLKO							//

// I2C master port
#define	MUX_PORT_SCL0_0						R08_P0L_PMUX					// SCL0_0 port
#define	MUX_MASK_SCL0_0						P03MUX							//
#define	MUX_I2CM_SCL0_0						SCL0							//

#define	MUX_PORT_SDA0_0						R08_P0H_PMUX					// SDA0_0 port
#define	MUX_MASK_SDA0_0						P04MUX							//
#define	MUX_I2CM_SDA0_0						SDA0							//

#define	MUX_PORT_SCL0_1						R08_P0L_PMUX					// SCL0_1 port
#define	MUX_MASK_SCL0_1						P03MUX							//
#define	MUX_I2CM_SCL0_1						SCL0							//

#define	MUX_PORT_SDA0_1						R08_P0H_PMUX					// SDA0_1 port
#define	MUX_MASK_SDA0_1						P04MUX							//
#define	MUX_I2CM_SDA0_1						SDA0							//

// I2C slave port
#define	MUX_PORT_SCL1						R08_P0L_PMUX					// SCL1_0 port
#define	MUX_MASK_SCL1						P03MUX							//
#define	MUX_I2CS_SCL1						SCL1							//

#define	MUX_PORT_SDA1						R08_P0H_PMUX					// SDA1_0 port
#define	MUX_MASK_SDA1						P04MUX							//
#define	MUX_I2CS_SDA1						SDA1							//

#define	MUX_PORT_BFR						R08_P1H_PMUX					// #BFR port
#define	MUX_MASK_BFR						P15MUX							//
#define	MUX_I2CS_BFR						xBFR							//

// OSC port
#define	MUX_PORT_OSC3						R08_P0L_PMUX					// OSC3 port
#define	MUX_MASK_OSC3						P01MUX							//
#define	MUX_OSC_OSC3						OSC3							//

#define	MUX_PORT_OSC4						R08_P0L_PMUX					// OSC4 port
#define	MUX_MASK_OSC4						P00MUX							//
#define	MUX_OSC_OSC4						OSC4							//

#define	MUX_PORT_FOUT1						R08_P0H_PMUX					// FOUT1 port
#define	MUX_MASK_FOUT1						P06MUX							//
#define	MUX_OSC_FOUT1						FOUT1							//

#define	MUX_PORT_FOUTH						R08_P0H_PMUX					// FOUTH port
#define	MUX_MASK_FOUTH						P07MUX							//
#define	MUX_OSC_FOUTH						FOUTH							//

// PWM port
#define	MUX_PORT_TOUT3						R08_P1L_PMUX					// TOUT3 port
#define	MUX_MASK_TOUT3						P12MUX							//
#define	MUX_T16E_TOUT3						TOUT3							//

#define	MUX_PORT_TOUTN3						R08_P1L_PMUX					// TOUTN3 port
#define	MUX_MASK_TOUTN3						P13MUX							//
#define	MUX_T16E_TOUTN3						TOUTN3							//

#define	MUX_PORT_TOUT4E						R08_P0L_PMUX					// TOUT4 port
#define	MUX_MASK_TOUT4E						P02MUX							//
#define	MUX_T16E_TOUT4E						TOUT4							//

#define	MUX_PORT_TOUTN4E					R08_P1L_PMUX					// TOUTN4 port
#define	MUX_MASK_TOUTN4E					P10MUX							//
#define	MUX_T16E_TOUTN4E					TOUTN4							//

// LCD port
#define	MUX_PORT_LFRO						R08_P0H_PMUX					// LFRO port
#define	MUX_MASK_LFRO						P06MUX							//
#define	MUX_LCD_LFRO						LFRO							//

// 8-bit OSC1 port
#define	MUX_PORT_TOUT4						R08_P0H_PMUX					// T8OUT port
#define	MUX_MASK_TOUT4						P05MUX							//
#define	MUX_T8OSC1_TOUT4					T8OUT							//

// debug port
#define	MUX_PORT_P41						R08_P2L_PMUX					// P41 port
#define	MUX_MASK_P41						P21MUX							//
#define	MUX_DBG_P41							P21								//

#define	MUX_PORT_P42						R08_P2L_PMUX					// P42 port
#define	MUX_MASK_P42						P22MUX							//
#define	MUX_DBG_P42							P22								//

// 16-bit timer port
#define	MUX_PORT_EXCL0						R08_P2L_PMUX					// EXCL0 port
#define	MUX_MASK_EXCL0						P20MUX							//
#define	MUX_T16_EXCL0						P20								//

#define	MUX_PORT_EXCL1						R08_P1H_PMUX					// EXCL1 port
#define	MUX_MASK_EXCL1						P17MUX							//
#define	MUX_T16_EXCL1						P17								//

#define	MUX_PORT_EXCL2						R08_P1H_PMUX					// EXCL2 port
#define	MUX_MASK_EXCL2						P16MUX							//
#define	MUX_T16_EXCL2						P16								//


/*****************************************************************************/
/* 0x5300-0x530c	PWM Timer(T16E)											 */
/*****************************************************************************/
#define T16E_OFFSET							(0x1300)
#define T16E_CHOFFSET						(0x0060)

#define PE_T16E

#define	T16E_CHANNEL2
#define T16E_INTLVL_CH0						R08_ITC_LV3H					// Ch0 interrupt level
#define T16E_INTLVL_CH1						R08_ITC_LV8L					// Ch1 interrupt level


/*****************************************************************************/
/* 0x5320-0x532a	MISC Registers(MISC)									 */
/*****************************************************************************/
#define MISC_OFFSET							(0x1320)

#define PE_MISC


/*****************************************************************************/
/* 0x5380-0x5386	ADC10SA(ADC)											 */
/*****************************************************************************/
#define ADC_OFFSET							(0x1380)

#define PE_ADC

#define	ADC_CHANNEL4
#define ADC_INTLVL							R08_ITC_LV9L					// interrupt level


/*****************************************************************************/
/* 0x53a0-0x53ae	RFC														 */
/*****************************************************************************/
#define RFC_OFFSET							(0x13a0)

#define PE_RFC

#define	RFC_CHANNEL1
#define RFC_INTLVL							R08_ITC_LV9H					// interrupt level


/*****************************************************************************/
/* 0x53c0-0x53e7	SEGRAM(SEG)												 */
/*****************************************************************************/
#define SEG_OFFSET							(0x13c0)


/*****************************************************************************/
/* etc																		 */
/*****************************************************************************/

#define PE_CURRENT_MEASURE
#define PE_SLEEP_HALT


/*****************************************************************************/
/* program groupe															 */
/*****************************************************************************/
// #undef is defined when it does the out that comments.

#define S1C17611_GROUPE_1
//#define S1C17611_GROUPE_2

#ifdef	S1C17611_GROUPE_1

//#undef	PE_PORT
//#undef	PE_OSC
//#undef	PE_T16
#undef	PE_T8F
#undef	PE_T16E
#undef	PE_T8OSC1
#undef	PE_CT
#undef	PE_SWT
#undef	PE_WDT
#undef	PE_UART
#undef	PE_UART_OSC3
#undef	PE_UART_IOSC
//#undef	PE_SPI
//#undef	PE_SPI_MASTER
//#undef	PE_SPI_SLAVE
//#undef	PE_I2CM
//#undef	PE_I2CS
//#undef	PE_LCD
//#undef	PE_SVD
//#undef	PE_RFC
#undef	PE_ADC
//#undef	PE_CURRENT_MEASURE
//#undef	PE_SLEEP_HALT
//#undef	PE_VD1

#else																	// S1C17611_GROUPE_2

#undef	PE_PORT
//#undef	PE_OSC
//#undef	PE_T16
//#undef	PE_T8F
//#undef	PE_T16E
//#undef	PE_T8OSC1
//#undef	PE_CT
//#undef	PE_SWT
//#undef	PE_WDT
//#undef	PE_UART
//#undef	PE_UART_OSC3
//#undef	PE_UART_IOSC
#undef	PE_SPI
#undef	PE_SPI_MASTER
#undef	PE_SPI_SLAVE
#undef	PE_I2CM
#undef	PE_I2CS
#undef	PE_LCD
#undef	PE_SVD
#undef	PE_RFC
//#undef	PE_ADC
#undef	PE_CURRENT_MEASURE
#undef	PE_SLEEP_HALT
//#undef	PE_VD1

#endif	// end of S1C17611_GROUPE_x


#endif	// end of S1C17611_PERIPHERAL_H_
